.text
.p2align 5
.globl _crypto_scalarmult_curve25519_athlon_mainloop
.globl crypto_scalarmult_curve25519_athlon_mainloop
_crypto_scalarmult_curve25519_athlon_mainloop:
crypto_scalarmult_curve25519_athlon_mainloop:
mov %esp,%eax
and $31,%eax
add $704,%eax
sub %eax,%esp
lea 256(%esp),%edx
lea 512(%esp),%ecx
fldl crypto_scalarmult_curve25519_athlon_two0
fldl crypto_scalarmult_curve25519_athlon_zero
movl %eax,160(%ecx)
movl %ebx,164(%ecx)
movl %esi,168(%ecx)
movl %edi,172(%ecx)
movl %ebp,176(%ecx)
movl 4(%esp,%eax),%ebx
fxch %st(1)
fstl 0(%esp)
fxch %st(1)
fstl 8(%esp)
fstl 16(%esp)
fstl 24(%esp)
fstl 32(%esp)
fstl 40(%esp)
fstl 48(%esp)
fstl -120(%edx)
fstl -112(%edx)
fstl -104(%edx)
fstl -96(%edx)
fstl -88(%edx)
fstl -80(%edx)
fstl -72(%edx)
fstl -64(%edx)
fstl -56(%edx)
fstl -48(%edx)
fstl -40(%edx)
fstl -32(%edx)
fstl -24(%edx)
fxch %st(1)
fstpl 64(%edx)
fstl 72(%edx)
fstl 80(%edx)
fstl 88(%edx)
fstl 96(%edx)
fstl 104(%edx)
fstl 112(%edx)
fstl 120(%edx)
fstl -128(%ecx)
fstpl -120(%ecx)
fldl 0(%ebx)
fldl 8(%ebx)
fldl 16(%ebx)
fldl 24(%ebx)
fxch %st(3)
fstl -16(%edx)
fstpl 56(%esp)
fldl 32(%ebx)
fxch %st(2)
fstl -8(%edx)
fstpl 64(%esp)
fldl 40(%ebx)
fxch %st(1)
fstl 0(%edx)
fstpl 72(%esp)
fldl 48(%ebx)
fxch %st(3)
fstl 8(%edx)
fstpl 80(%esp)
fldl 56(%ebx)
fxch %st(2)
fstl 16(%edx)
fstpl 88(%esp)
fldl 64(%ebx)
fxch %st(1)
fstl 24(%edx)
fstpl 96(%esp)
fldl 72(%ebx)
fxch %st(3)
fstl 32(%edx)
fstpl 104(%esp)
fxch %st(1)
fstl 40(%edx)
fstpl 112(%esp)
fstl 48(%edx)
fstpl 120(%esp)
fstl 56(%edx)
fstpl -128(%edx)
movl 8(%esp,%eax),%ebx
mov  $28,%edi
mov  $31,%ebp
movl 28(%ebx),%esi
rol  $1,%esi
._morebytes:
movl %edi,188(%ecx)
._morebits:
rol  $1,%esi
movl %esi,180(%ecx)
movl %ebp,184(%ecx)
and  $1,%esi
movl  $0x43300000,-108(%ecx)
movl %esi,-112(%ecx)
fldl -96(%edx)
fldl 0(%esp)
fadd %st(0),%st(1)
fsubl -96(%edx)
fldl 64(%edx)
fldl -16(%edx)
fadd %st(0),%st(1)
fsubl 64(%edx)
fldl -88(%edx)
fldl 8(%esp)
fadd %st(0),%st(1)
fsubl -88(%edx)
fxch %st(5)
fstpl 0(%esp)
fxch %st(3)
fstpl -96(%edx)
fldl 72(%edx)
fldl -8(%edx)
fadd %st(0),%st(1)
fsubl 72(%edx)
fxch %st(3)
fstpl -16(%edx)
fxch %st(1)
fstpl 64(%edx)
fldl -80(%edx)
fldl 16(%esp)
fadd %st(0),%st(1)
fsubl -80(%edx)
fxch %st(4)
fstpl 8(%esp)
fxch %st(4)
fstpl -88(%edx)
fldl 80(%edx)
fldl 0(%edx)
fadd %st(0),%st(1)
fsubl 80(%edx)
fxch %st(2)
fstpl -8(%edx)
fxch %st(2)
fstpl 72(%edx)
fldl -72(%edx)
fldl 24(%esp)
fadd %st(0),%st(1)
fsubl -72(%edx)
fxch %st(5)
fstpl 16(%esp)
fxch %st(3)
fstpl -80(%edx)
fldl 88(%edx)
fldl 8(%edx)
fadd %st(0),%st(1)
fsubl 88(%edx)
fxch %st(3)
fstpl 0(%edx)
fxch %st(1)
fstpl 80(%edx)
fldl -64(%edx)
fldl 32(%esp)
fadd %st(0),%st(1)
fsubl -64(%edx)
fxch %st(4)
fstpl 24(%esp)
fxch %st(4)
fstpl -72(%edx)
fldl 96(%edx)
fldl 16(%edx)
fadd %st(0),%st(1)
fsubl 96(%edx)
fxch %st(2)
fstpl 8(%edx)
fxch %st(2)
fstpl 88(%edx)
fldl -56(%edx)
fldl 40(%esp)
fadd %st(0),%st(1)
fsubl -56(%edx)
fxch %st(5)
fstpl 32(%esp)
fxch %st(3)
fstpl -64(%edx)
fldl 104(%edx)
fldl 24(%edx)
fadd %st(0),%st(1)
fsubl 104(%edx)
fxch %st(3)
fstpl 16(%edx)
fxch %st(1)
fstpl 96(%edx)
fldl -48(%edx)
fldl 48(%esp)
fadd %st(0),%st(1)
fsubl -48(%edx)
fxch %st(4)
fstpl 40(%esp)
fxch %st(4)
fstpl -56(%edx)
fldl 112(%edx)
fldl 32(%edx)
fadd %st(0),%st(1)
fsubl 112(%edx)
fxch %st(2)
fstpl 24(%edx)
fxch %st(2)
fstpl 104(%edx)
fldl -40(%edx)
fldl -120(%edx)
fadd %st(0),%st(1)
fsubl -40(%edx)
fxch %st(5)
fstpl 48(%esp)
fxch %st(3)
fstpl -48(%edx)
fldl 120(%edx)
fldl 40(%edx)
fadd %st(0),%st(1)
fsubl 120(%edx)
fxch %st(3)
fstpl 32(%edx)
fxch %st(1)
fstpl 112(%edx)
fldl -32(%edx)
fldl -112(%edx)
fadd %st(0),%st(1)
fsubl -32(%edx)
fxch %st(4)
fstpl -120(%edx)
fxch %st(4)
fstpl -40(%edx)
fldl -128(%ecx)
fldl 48(%edx)
fadd %st(0),%st(1)
fsubl -128(%ecx)
fxch %st(2)
fstpl 40(%edx)
fxch %st(2)
fstpl 120(%edx)
fldl -24(%edx)
fldl -104(%edx)
fadd %st(0),%st(1)
fsubl -24(%edx)
fxch %st(5)
fstpl -112(%edx)
fxch %st(3)
fstpl -32(%edx)
fldl -120(%ecx)
fldl 56(%edx)
fadd %st(0),%st(1)
fsubl -120(%ecx)
fxch %st(3)
fstpl 48(%edx)
fxch %st(1)
fstpl -128(%ecx)
fldl -112(%ecx)
fsubl crypto_scalarmult_curve25519_athlon_in0offset
fldl crypto_scalarmult_curve25519_athlon_two0
fsub %st(1),%st(0)
fxch %st(4)
fstpl -104(%edx)
fxch %st(4)
fstpl -24(%edx)
fstpl 56(%edx)
fstpl -120(%ecx)
fxch %st(1)
fstl 136(%ecx)
fldl 0(%esp)
fmul %st(2),%st(0)
fldl -16(%edx)
fmul %st(2),%st(0)
faddp %st(0),%st(1)
fldl 8(%esp)
fmul %st(3),%st(0)
fldl -8(%edx)
fmul %st(3),%st(0)
faddp %st(0),%st(1)
fldl 16(%esp)
fmul %st(4),%st(0)
fldl 0(%edx)
fmul %st(4),%st(0)
faddp %st(0),%st(1)
fldl 24(%esp)
fmul %st(5),%st(0)
fldl 8(%edx)
fmul %st(5),%st(0)
faddp %st(0),%st(1)
fxch %st(3)
fstpl -112(%ecx)
fldl 32(%esp)
fmul %st(5),%st(0)
fldl 16(%edx)
fmul %st(5),%st(0)
faddp %st(0),%st(1)
fxch %st(2)
fstpl -104(%ecx)
fldl 40(%esp)
fmul %st(5),%st(0)
fldl 24(%edx)
fmul %st(5),%st(0)
faddp %st(0),%st(1)
fxch %st(1)
fstpl -96(%ecx)
fldl 48(%esp)
fmul %st(5),%st(0)
fldl 32(%edx)
fmul %st(5),%st(0)
faddp %st(0),%st(1)
fxch %st(3)
fstpl -88(%ecx)
fldl -120(%edx)
fmul %st(5),%st(0)
fldl 40(%edx)
fmul %st(5),%st(0)
faddp %st(0),%st(1)
fxch %st(2)
fstpl -80(%ecx)
fldl -112(%edx)
fmul %st(5),%st(0)
fldl 48(%edx)
fmul %st(5),%st(0)
faddp %st(0),%st(1)
fxch %st(1)
fstpl -72(%ecx)
fldl -104(%edx)
fmul %st(5),%st(0)
fldl 56(%edx)
fmul %st(5),%st(0)
faddp %st(0),%st(1)
fxch %st(3)
fstpl -64(%ecx)
fldl -96(%edx)
fmul %st(5),%st(0)
fldl 64(%edx)
fmul %st(5),%st(0)
faddp %st(0),%st(1)
fxch %st(2)
fstpl -56(%ecx)
fldl -88(%edx)
fmul %st(5),%st(0)
fldl 72(%edx)
fmul %st(5),%st(0)
faddp %st(0),%st(1)
fxch %st(1)
fstpl -48(%ecx)
fldl -80(%edx)
fmul %st(5),%st(0)
fldl 80(%edx)
fmul %st(5),%st(0)
faddp %st(0),%st(1)
fxch %st(3)
fstpl -40(%ecx)
fldl -72(%edx)
fmul %st(5),%st(0)
fldl 88(%edx)
fmul %st(5),%st(0)
faddp %st(0),%st(1)
fxch %st(2)
fstpl -32(%ecx)
fldl -64(%edx)
fmul %st(5),%st(0)
fldl 96(%edx)
fmul %st(5),%st(0)
faddp %st(0),%st(1)
fxch %st(1)
fstpl -24(%ecx)
fldl -56(%edx)
fmul %st(5),%st(0)
fldl 104(%edx)
fmul %st(5),%st(0)
faddp %st(0),%st(1)
fxch %st(3)
fstpl -16(%ecx)
fldl -48(%edx)
fmul %st(5),%st(0)
fldl 112(%edx)
fmul %st(5),%st(0)
faddp %st(0),%st(1)
fxch %st(2)
fstpl -8(%ecx)
fldl -40(%edx)
fmul %st(5),%st(0)
fldl 120(%edx)
fmul %st(5),%st(0)
faddp %st(0),%st(1)
fxch %st(1)
fstpl 0(%ecx)
fldl -32(%edx)
fmul %st(5),%st(0)
fldl -128(%ecx)
fmul %st(5),%st(0)
faddp %st(0),%st(1)
fxch %st(3)
fstpl 8(%ecx)
fldl -24(%edx)
fmulp %st(0),%st(5)
fldl -120(%ecx)
fmulp %st(0),%st(4)
fxch %st(3)
faddp %st(0),%st(4)
fstpl 16(%ecx)
fxch %st(1)
fstpl 24(%ecx)
fstpl 32(%ecx)
fstpl 40(%ecx)
fldl -24(%edx)
fmull 56(%edx)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -96(%edx)
fmull 48(%edx)
faddp %st(0),%st(1)
fldl -88(%edx)
fmull 40(%edx)
faddp %st(0),%st(1)
fldl -96(%edx)
fmull 56(%edx)
fldl -80(%edx)
fmull 32(%edx)
faddp %st(0),%st(2)
fldl -88(%edx)
fmull 48(%edx)
faddp %st(0),%st(1)
fldl -72(%edx)
fmull 24(%edx)
faddp %st(0),%st(2)
fldl -80(%edx)
fmull 40(%edx)
faddp %st(0),%st(1)
fldl -64(%edx)
fmull 16(%edx)
faddp %st(0),%st(2)
fldl -72(%edx)
fmull 32(%edx)
faddp %st(0),%st(1)
fldl -88(%edx)
fmull 56(%edx)
fldl -56(%edx)
fmull 8(%edx)
faddp %st(0),%st(3)
fldl -64(%edx)
fmull 24(%edx)
faddp %st(0),%st(2)
fldl -80(%edx)
fmull 48(%edx)
faddp %st(0),%st(1)
fldl -48(%edx)
fmull 0(%edx)
faddp %st(0),%st(3)
fldl -56(%edx)
fmull 16(%edx)
faddp %st(0),%st(2)
fldl -72(%edx)
fmull 40(%edx)
faddp %st(0),%st(1)
fldl -40(%edx)
fmull -8(%edx)
faddp %st(0),%st(3)
fldl -48(%edx)
fmull 8(%edx)
faddp %st(0),%st(2)
fldl -64(%edx)
fmull 32(%edx)
faddp %st(0),%st(1)
fldl -32(%edx)
fmull -16(%edx)
faddp %st(0),%st(3)
fldl -40(%edx)
fmull 0(%edx)
faddp %st(0),%st(2)
fldl -56(%edx)
fmull 24(%edx)
faddp %st(0),%st(1)
fldl -80(%edx)
fmull 56(%edx)
fldl -48(%edx)
fmull 16(%edx)
faddp %st(0),%st(2)
fldl -32(%edx)
fmull -8(%edx)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(4),%st(0)
fldl -72(%edx)
fmull 48(%edx)
faddp %st(0),%st(2)
fldl -40(%edx)
fmull 8(%edx)
faddp %st(0),%st(3)
fldl -24(%edx)
fmull -16(%edx)
faddp %st(0),%st(4)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fldl -64(%edx)
fmull 40(%edx)
faddp %st(0),%st(2)
fldl -72(%edx)
fmull 56(%edx)
fldl -32(%edx)
fmull 0(%edx)
faddp %st(0),%st(4)
fxch %st(1)
fadd %st(0),%st(4)
fldl -56(%edx)
fmull 32(%edx)
faddp %st(0),%st(3)
fldl -64(%edx)
fmull 48(%edx)
faddp %st(0),%st(2)
fsubrp %st(0),%st(5)
fldl crypto_scalarmult_curve25519_athlon_alpha255
fadd %st(4),%st(0)
fldl -48(%edx)
fmull 24(%edx)
faddp %st(0),%st(3)
fldl -56(%edx)
fmull 40(%edx)
faddp %st(0),%st(2)
fldl -24(%edx)
fmull -8(%edx)
faddp %st(0),%st(4)
fsubl crypto_scalarmult_curve25519_athlon_alpha255
fldl -40(%edx)
fmull 16(%edx)
faddp %st(0),%st(3)
fldl -64(%edx)
fmull 56(%edx)
fldl -48(%edx)
fmull 32(%edx)
faddp %st(0),%st(3)
fldl -32(%edx)
fmull 8(%edx)
faddp %st(0),%st(4)
fxch %st(1)
fadd %st(0),%st(4)
fsubrp %st(0),%st(5)
fxch %st(5)
fstpl 64(%ecx)
fldl -56(%edx)
fmull 48(%edx)
faddp %st(0),%st(5)
fldl -40(%edx)
fmull 24(%edx)
faddp %st(0),%st(1)
fldl -24(%edx)
fmull 0(%edx)
faddp %st(0),%st(2)
fxch %st(2)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -48(%edx)
fmull 40(%edx)
faddp %st(0),%st(5)
fldl -32(%edx)
fmull 16(%edx)
faddp %st(0),%st(3)
fxch %st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -96(%edx)
fmull -16(%edx)
faddp %st(0),%st(2)
fxch %st(3)
fstpl 72(%ecx)
fldl -56(%edx)
fmull 56(%edx)
fldl -40(%edx)
fmull 32(%edx)
faddp %st(0),%st(5)
fldl -24(%edx)
fmull 8(%edx)
faddp %st(0),%st(3)
fldl -96(%edx)
fmull -8(%edx)
faddp %st(0),%st(4)
fldl crypto_scalarmult_curve25519_athlon_alpha26
fadd %st(2),%st(0)
fldl -48(%edx)
fmull 48(%edx)
faddp %st(0),%st(2)
fldl -32(%edx)
fmull 24(%edx)
faddp %st(0),%st(6)
fxch %st(3)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -88(%edx)
fmull -16(%edx)
faddp %st(0),%st(5)
fxch %st(3)
fsubl crypto_scalarmult_curve25519_athlon_alpha26
fldl -40(%edx)
fmull 40(%edx)
faddp %st(0),%st(2)
fldl -24(%edx)
fmull 16(%edx)
faddp %st(0),%st(6)
fldl -96(%edx)
fmull 0(%edx)
faddp %st(0),%st(4)
fadd %st(0),%st(4)
fsubrp %st(0),%st(2)
fldl -48(%edx)
fmull 56(%edx)
fldl -32(%edx)
fmull 32(%edx)
faddp %st(0),%st(2)
fxch %st(5)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -88(%edx)
fmull -8(%edx)
faddp %st(0),%st(4)
fldl crypto_scalarmult_curve25519_athlon_alpha51
fadd %st(5),%st(0)
fldl -40(%edx)
fmull 48(%edx)
faddp %st(0),%st(7)
fldl -24(%edx)
fmull 24(%edx)
faddp %st(0),%st(3)
fldl -96(%edx)
fmull 8(%edx)
faddp %st(0),%st(2)
fldl -80(%edx)
fmull -16(%edx)
faddp %st(0),%st(5)
fsubl crypto_scalarmult_curve25519_athlon_alpha51
fxch %st(3)
fstpl 48(%ecx)
fldl -32(%edx)
fmull 40(%edx)
faddp %st(0),%st(6)
fxch %st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -88(%edx)
fmull 0(%edx)
faddp %st(0),%st(2)
fxch %st(2)
fadd %st(0),%st(3)
fsubrp %st(0),%st(4)
fldl -40(%edx)
fmull 56(%edx)
fldl -24(%edx)
fmull 32(%edx)
faddp %st(0),%st(6)
fldl -96(%edx)
fmull 16(%edx)
faddp %st(0),%st(3)
fldl -80(%edx)
fmull -8(%edx)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha77
fadd %st(4),%st(0)
fldl -32(%edx)
fmull 48(%edx)
faddp %st(0),%st(2)
fxch %st(6)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -88(%edx)
fmull 8(%edx)
faddp %st(0),%st(4)
fldl -72(%edx)
fmull -16(%edx)
faddp %st(0),%st(3)
fxch %st(6)
fsubl crypto_scalarmult_curve25519_athlon_alpha77
fxch %st(5)
fstpl 56(%ecx)
fldl -24(%edx)
fmull 40(%edx)
faddp %st(0),%st(1)
fldl -96(%edx)
fmull 24(%edx)
faddp %st(0),%st(6)
fldl -80(%edx)
fmull 0(%edx)
faddp %st(0),%st(3)
fxch %st(4)
fadd %st(0),%st(1)
fsubrp %st(0),%st(3)
fldl -32(%edx)
fmull 56(%edx)
fxch %st(4)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -88(%edx)
fmull 16(%edx)
faddp %st(0),%st(6)
fldl -72(%edx)
fmull -8(%edx)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha102
fadd %st(2),%st(0)
fldl -24(%edx)
fmull 48(%edx)
faddp %st(0),%st(6)
fldl -96(%edx)
fmull 32(%edx)
faddp %st(0),%st(2)
fldl -80(%edx)
fmull 8(%edx)
faddp %st(0),%st(7)
fldl -64(%edx)
fmull -16(%edx)
faddp %st(0),%st(4)
fsubl crypto_scalarmult_curve25519_athlon_alpha102
fxch %st(4)
fstpl -24(%edx)
fxch %st(4)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -88(%edx)
fmull 24(%edx)
faddp %st(0),%st(5)
fldl -72(%edx)
fmull 0(%edx)
faddp %st(0),%st(6)
fxch %st(3)
fadd %st(0),%st(2)
fsubrp %st(0),%st(1)
fldl -96(%edx)
fmull 40(%edx)
faddp %st(0),%st(3)
fldl -80(%edx)
fmull 16(%edx)
faddp %st(0),%st(4)
fldl -64(%edx)
fmull -8(%edx)
faddp %st(0),%st(5)
fldl crypto_scalarmult_curve25519_athlon_alpha128
fadd %st(2),%st(0)
fldl -88(%edx)
fmull 32(%edx)
faddp %st(0),%st(4)
fldl -72(%edx)
fmull 8(%edx)
faddp %st(0),%st(5)
fldl -56(%edx)
fmull -16(%edx)
faddp %st(0),%st(6)
fsubl crypto_scalarmult_curve25519_athlon_alpha128
fxch %st(1)
fstpl -96(%edx)
fldl -80(%edx)
fmull 24(%edx)
faddp %st(0),%st(3)
fldl -64(%edx)
fmull 0(%edx)
faddp %st(0),%st(4)
fadd %st(0),%st(4)
fsubrp %st(0),%st(1)
fstpl -88(%edx)
fldl -72(%edx)
fmull 16(%edx)
faddp %st(0),%st(1)
fldl -56(%edx)
fmull -8(%edx)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha153
fadd %st(3),%st(0)
fldl -64(%edx)
fmull 8(%edx)
faddp %st(0),%st(2)
fldl -48(%edx)
fmull -16(%edx)
faddp %st(0),%st(3)
fsubl crypto_scalarmult_curve25519_athlon_alpha153
fldl -56(%edx)
fmull 0(%edx)
faddp %st(0),%st(2)
fadd %st(0),%st(2)
fsubrp %st(0),%st(3)
fxch %st(2)
fstpl -80(%edx)
fldl -48(%edx)
fmull -8(%edx)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha179
fadd %st(1),%st(0)
fldl -40(%edx)
fmull -16(%edx)
faddp %st(0),%st(3)
fsubl crypto_scalarmult_curve25519_athlon_alpha179
fldl 64(%ecx)
fldl 72(%ecx)
fxch %st(2)
fadd %st(0),%st(4)
fsubrp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha204
fadd %st(4),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha204
fadd %st(0),%st(1)
fsubrp %st(0),%st(4)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fsubr %st(0),%st(1)
faddp %st(0),%st(2)
fxch %st(2)
fstpl -72(%edx)
fxch %st(2)
fstpl -64(%edx)
fstpl -56(%edx)
fstpl -48(%edx)
fldl -104(%edx)
fmull -120(%ecx)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -128(%ecx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull 120(%edx)
faddp %st(0),%st(1)
fldl 0(%esp)
fmull -120(%ecx)
fldl 16(%esp)
fmull 112(%edx)
faddp %st(0),%st(2)
fldl 8(%esp)
fmull -128(%ecx)
faddp %st(0),%st(1)
fldl 24(%esp)
fmull 104(%edx)
faddp %st(0),%st(2)
fldl 16(%esp)
fmull 120(%edx)
faddp %st(0),%st(1)
fldl 32(%esp)
fmull 96(%edx)
faddp %st(0),%st(2)
fldl 24(%esp)
fmull 112(%edx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull -120(%ecx)
fldl 40(%esp)
fmull 88(%edx)
faddp %st(0),%st(3)
fldl 32(%esp)
fmull 104(%edx)
faddp %st(0),%st(2)
fldl 16(%esp)
fmull -128(%ecx)
faddp %st(0),%st(1)
fldl 48(%esp)
fmull 80(%edx)
faddp %st(0),%st(3)
fldl 40(%esp)
fmull 96(%edx)
faddp %st(0),%st(2)
fldl 24(%esp)
fmull 120(%edx)
faddp %st(0),%st(1)
fldl -120(%edx)
fmull 72(%edx)
faddp %st(0),%st(3)
fldl 48(%esp)
fmull 88(%edx)
faddp %st(0),%st(2)
fldl 32(%esp)
fmull 112(%edx)
faddp %st(0),%st(1)
fldl -112(%edx)
fmull 64(%edx)
faddp %st(0),%st(3)
fldl -120(%edx)
fmull 80(%edx)
faddp %st(0),%st(2)
fldl 40(%esp)
fmull 104(%edx)
faddp %st(0),%st(1)
fldl 16(%esp)
fmull -120(%ecx)
fldl 48(%esp)
fmull 96(%edx)
faddp %st(0),%st(2)
fldl -112(%edx)
fmull 72(%edx)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(4),%st(0)
fldl 24(%esp)
fmull -128(%ecx)
faddp %st(0),%st(2)
fldl -120(%edx)
fmull 88(%edx)
faddp %st(0),%st(3)
fldl -104(%edx)
fmull 64(%edx)
faddp %st(0),%st(4)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fldl 32(%esp)
fmull 120(%edx)
faddp %st(0),%st(2)
fldl 24(%esp)
fmull -120(%ecx)
fldl -112(%edx)
fmull 80(%edx)
faddp %st(0),%st(4)
fxch %st(1)
fadd %st(0),%st(4)
fldl 40(%esp)
fmull 112(%edx)
faddp %st(0),%st(3)
fldl 32(%esp)
fmull -128(%ecx)
faddp %st(0),%st(2)
fsubrp %st(0),%st(5)
fldl crypto_scalarmult_curve25519_athlon_alpha255
fadd %st(4),%st(0)
fldl 48(%esp)
fmull 104(%edx)
faddp %st(0),%st(3)
fldl 40(%esp)
fmull 120(%edx)
faddp %st(0),%st(2)
fldl -104(%edx)
fmull 72(%edx)
faddp %st(0),%st(4)
fsubl crypto_scalarmult_curve25519_athlon_alpha255
fldl -120(%edx)
fmull 96(%edx)
faddp %st(0),%st(3)
fldl 32(%esp)
fmull -120(%ecx)
fldl 48(%esp)
fmull 112(%edx)
faddp %st(0),%st(3)
fldl -112(%edx)
fmull 88(%edx)
faddp %st(0),%st(4)
fxch %st(1)
fadd %st(0),%st(4)
fsubrp %st(0),%st(5)
fxch %st(5)
fstpl 8(%edx)
fldl 40(%esp)
fmull -128(%ecx)
faddp %st(0),%st(5)
fldl -120(%edx)
fmull 104(%edx)
faddp %st(0),%st(1)
fldl -104(%edx)
fmull 80(%edx)
faddp %st(0),%st(2)
fxch %st(2)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 48(%esp)
fmull 120(%edx)
faddp %st(0),%st(5)
fldl -112(%edx)
fmull 96(%edx)
faddp %st(0),%st(3)
fxch %st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull 64(%edx)
faddp %st(0),%st(2)
fxch %st(3)
fstpl 16(%edx)
fldl 40(%esp)
fmull -120(%ecx)
fldl -120(%edx)
fmull 112(%edx)
faddp %st(0),%st(5)
fldl -104(%edx)
fmull 88(%edx)
faddp %st(0),%st(3)
fldl 0(%esp)
fmull 72(%edx)
faddp %st(0),%st(4)
fldl crypto_scalarmult_curve25519_athlon_alpha26
fadd %st(2),%st(0)
fldl 48(%esp)
fmull -128(%ecx)
faddp %st(0),%st(2)
fldl -112(%edx)
fmull 104(%edx)
faddp %st(0),%st(6)
fxch %st(3)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 8(%esp)
fmull 64(%edx)
faddp %st(0),%st(5)
fxch %st(3)
fsubl crypto_scalarmult_curve25519_athlon_alpha26
fldl -120(%edx)
fmull 120(%edx)
faddp %st(0),%st(2)
fldl -104(%edx)
fmull 96(%edx)
faddp %st(0),%st(6)
fldl 0(%esp)
fmull 80(%edx)
faddp %st(0),%st(4)
fadd %st(0),%st(4)
fsubrp %st(0),%st(2)
fldl 48(%esp)
fmull -120(%ecx)
fldl -112(%edx)
fmull 112(%edx)
faddp %st(0),%st(2)
fxch %st(5)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 8(%esp)
fmull 72(%edx)
faddp %st(0),%st(4)
fldl crypto_scalarmult_curve25519_athlon_alpha51
fadd %st(5),%st(0)
fldl -120(%edx)
fmull -128(%ecx)
faddp %st(0),%st(7)
fldl -104(%edx)
fmull 104(%edx)
faddp %st(0),%st(3)
fldl 0(%esp)
fmull 88(%edx)
faddp %st(0),%st(2)
fldl 16(%esp)
fmull 64(%edx)
faddp %st(0),%st(5)
fsubl crypto_scalarmult_curve25519_athlon_alpha51
fxch %st(3)
fstpl -40(%edx)
fldl -112(%edx)
fmull 120(%edx)
faddp %st(0),%st(6)
fxch %st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 8(%esp)
fmull 80(%edx)
faddp %st(0),%st(2)
fxch %st(2)
fadd %st(0),%st(3)
fsubrp %st(0),%st(4)
fldl -120(%edx)
fmull -120(%ecx)
fldl -104(%edx)
fmull 112(%edx)
faddp %st(0),%st(6)
fldl 0(%esp)
fmull 96(%edx)
faddp %st(0),%st(3)
fldl 16(%esp)
fmull 72(%edx)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha77
fadd %st(4),%st(0)
fldl -112(%edx)
fmull -128(%ecx)
faddp %st(0),%st(2)
fxch %st(6)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 8(%esp)
fmull 88(%edx)
faddp %st(0),%st(4)
fldl 24(%esp)
fmull 64(%edx)
faddp %st(0),%st(3)
fxch %st(6)
fsubl crypto_scalarmult_curve25519_athlon_alpha77
fxch %st(5)
fstpl -32(%edx)
fldl -104(%edx)
fmull 120(%edx)
faddp %st(0),%st(1)
fldl 0(%esp)
fmull 104(%edx)
faddp %st(0),%st(6)
fldl 16(%esp)
fmull 80(%edx)
faddp %st(0),%st(3)
fxch %st(4)
fadd %st(0),%st(1)
fsubrp %st(0),%st(3)
fldl -112(%edx)
fmull -120(%ecx)
fxch %st(4)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 8(%esp)
fmull 96(%edx)
faddp %st(0),%st(6)
fldl 24(%esp)
fmull 72(%edx)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha102
fadd %st(2),%st(0)
fldl -104(%edx)
fmull -128(%ecx)
faddp %st(0),%st(6)
fldl 0(%esp)
fmull 112(%edx)
faddp %st(0),%st(2)
fldl 16(%esp)
fmull 88(%edx)
faddp %st(0),%st(7)
fldl 32(%esp)
fmull 64(%edx)
faddp %st(0),%st(4)
fsubl crypto_scalarmult_curve25519_athlon_alpha102
fxch %st(4)
fstpl -104(%edx)
fxch %st(4)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 8(%esp)
fmull 104(%edx)
faddp %st(0),%st(5)
fldl 24(%esp)
fmull 80(%edx)
faddp %st(0),%st(6)
fxch %st(3)
fadd %st(0),%st(2)
fsubrp %st(0),%st(1)
fldl 0(%esp)
fmull 120(%edx)
faddp %st(0),%st(3)
fldl 16(%esp)
fmull 96(%edx)
faddp %st(0),%st(4)
fldl 32(%esp)
fmull 72(%edx)
faddp %st(0),%st(5)
fldl crypto_scalarmult_curve25519_athlon_alpha128
fadd %st(2),%st(0)
fldl 8(%esp)
fmull 112(%edx)
faddp %st(0),%st(4)
fldl 24(%esp)
fmull 88(%edx)
faddp %st(0),%st(5)
fldl 40(%esp)
fmull 64(%edx)
faddp %st(0),%st(6)
fsubl crypto_scalarmult_curve25519_athlon_alpha128
fxch %st(1)
fstpl -16(%edx)
fldl 16(%esp)
fmull 104(%edx)
faddp %st(0),%st(3)
fldl 32(%esp)
fmull 80(%edx)
faddp %st(0),%st(4)
fadd %st(0),%st(4)
fsubrp %st(0),%st(1)
fstpl -8(%edx)
fldl 24(%esp)
fmull 96(%edx)
faddp %st(0),%st(1)
fldl 40(%esp)
fmull 72(%edx)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha153
fadd %st(3),%st(0)
fldl 32(%esp)
fmull 88(%edx)
faddp %st(0),%st(2)
fldl 48(%esp)
fmull 64(%edx)
faddp %st(0),%st(3)
fsubl crypto_scalarmult_curve25519_athlon_alpha153
fldl 40(%esp)
fmull 80(%edx)
faddp %st(0),%st(2)
fadd %st(0),%st(2)
fsubrp %st(0),%st(3)
fxch %st(2)
fstpl 0(%edx)
fldl 48(%esp)
fmull 72(%edx)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha179
fadd %st(1),%st(0)
fldl -120(%edx)
fmull 64(%edx)
faddp %st(0),%st(3)
fsubl crypto_scalarmult_curve25519_athlon_alpha179
fldl 8(%edx)
fldl 16(%edx)
fxch %st(2)
fadd %st(0),%st(4)
fsubrp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha204
fadd %st(4),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha204
fadd %st(0),%st(1)
fsubrp %st(0),%st(4)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fsubr %st(0),%st(1)
faddp %st(0),%st(2)
fxch %st(2)
fstpl 8(%edx)
fxch %st(2)
fstpl 16(%edx)
fstpl 24(%edx)
fstpl 32(%edx)
fldl -40(%ecx)
fmul %st(0),%st(0)
fldl -112(%ecx)
fadd %st(0),%st(0)
fldl -104(%ecx)
fadd %st(0),%st(0)
fldl -96(%ecx)
fadd %st(0),%st(0)
fldl -56(%ecx)
fxch %st(4)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -40(%ecx)
fmul %st(4),%st(0)
fldl -48(%ecx)
fmul %st(4),%st(0)
faddp %st(0),%st(1)
fxch %st(4)
fstl 0(%esp)
fxch %st(3)
fstl 8(%esp)
fxch %st(3)
fmull -48(%ecx)
faddp %st(0),%st(1)
fldl -64(%ecx)
fxch %st(5)
fmul %st(0),%st(3)
fxch %st(3)
faddp %st(0),%st(1)
fxch %st(2)
fadd %st(0),%st(0)
fldl -56(%ecx)
fmul %st(2),%st(0)
faddp %st(0),%st(4)
fxch %st(1)
fstl 16(%esp)
fldl -72(%ecx)
fxch %st(5)
fmul %st(0),%st(1)
fxch %st(1)
faddp %st(0),%st(3)
fadd %st(0),%st(0)
fstpl 48(%esp)
fldl -88(%ecx)
fadd %st(0),%st(0)
fstl 24(%esp)
fldl -64(%ecx)
fmul %st(1),%st(0)
faddp %st(0),%st(4)
fmul %st(4),%st(0)
faddp %st(0),%st(2)
fxch %st(3)
fadd %st(0),%st(0)
fstpl 40(%esp)
fldl -80(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fsubr %st(0),%st(1)
fldl 8(%esp)
fldl -40(%ecx)
fmul %st(0),%st(1)
fldl 16(%esp)
fmul %st(0),%st(1)
fldl -48(%ecx)
fmul %st(0),%st(1)
fxch %st(1)
faddp %st(0),%st(3)
fldl 24(%esp)
fmul %st(0),%st(1)
fxch %st(1)
faddp %st(0),%st(2)
fldl -80(%ecx)
fadd %st(0),%st(0)
fstl 32(%esp)
fmull -72(%ecx)
faddp %st(0),%st(6)
fxch %st(3)
faddp %st(0),%st(5)
fldl crypto_scalarmult_curve25519_athlon_alpha255
fadd %st(5),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha255
fsubr %st(0),%st(5)
fldl -56(%ecx)
fmul %st(0),%st(4)
fxch %st(4)
faddp %st(0),%st(3)
fldl 32(%esp)
fmul %st(0),%st(4)
fxch %st(4)
faddp %st(0),%st(2)
fldl -64(%ecx)
fmul %st(0),%st(4)
fxch %st(4)
faddp %st(0),%st(3)
fxch %st(3)
fmull 40(%esp)
faddp %st(0),%st(1)
fxch %st(3)
fstpl -120(%edx)
fldl -72(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
fxch %st(2)
fmull crypto_scalarmult_curve25519_athlon_scale
fxch %st(3)
fstpl -112(%edx)
faddp %st(0),%st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 24(%esp)
fmull -40(%ecx)
fldl -112(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(2)
fldl 32(%esp)
fmull -48(%ecx)
faddp %st(0),%st(1)
fldl 0(%esp)
fmull -104(%ecx)
faddp %st(0),%st(3)
fldl 40(%esp)
fmull -56(%ecx)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha26
fadd %st(2),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha26
fsubr %st(0),%st(2)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha51
fadd %st(3),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha51
fsubr %st(0),%st(3)
fldl -64(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(2)
fxch %st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -96(%ecx)
faddp %st(0),%st(1)
fldl -104(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha77
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha77
fsubr %st(0),%st(1)
fxch %st(2)
fstpl 64(%edx)
fldl 32(%esp)
fmull -40(%ecx)
fldl 40(%esp)
fmull -48(%ecx)
faddp %st(0),%st(1)
fldl 48(%esp)
fmull -56(%ecx)
faddp %st(0),%st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -88(%ecx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull -96(%ecx)
faddp %st(0),%st(1)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha102
fadd %st(2),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha102
fsubr %st(0),%st(2)
fxch %st(3)
fstpl 72(%edx)
fldl 40(%esp)
fmull -40(%ecx)
fldl 48(%esp)
fmull -48(%ecx)
faddp %st(0),%st(1)
fldl -56(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -80(%ecx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull -88(%ecx)
faddp %st(0),%st(1)
fldl -96(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha128
fadd %st(3),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha128
fsubr %st(0),%st(3)
fxch %st(1)
fstpl 80(%edx)
fldl 48(%esp)
fldl -40(%ecx)
fmul %st(0),%st(1)
fmul %st(5),%st(0)
fxch %st(5)
fmull -48(%ecx)
faddp %st(0),%st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -72(%ecx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull -80(%ecx)
faddp %st(0),%st(1)
fldl 16(%esp)
fmull -88(%ecx)
faddp %st(0),%st(1)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha153
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha153
fsubr %st(0),%st(1)
fxch %st(2)
fstpl 88(%edx)
fldl -48(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(4)
fxch %st(3)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -64(%ecx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull -72(%ecx)
faddp %st(0),%st(1)
fldl 16(%esp)
fmull -80(%ecx)
faddp %st(0),%st(1)
fldl -88(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha179
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha179
fsubr %st(0),%st(1)
fldl -48(%ecx)
fadd %st(0),%st(0)
fmull -40(%ecx)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -56(%ecx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull -64(%ecx)
faddp %st(0),%st(1)
fldl 16(%esp)
fmull -72(%ecx)
faddp %st(0),%st(1)
fldl 24(%esp)
fmull -80(%ecx)
faddp %st(0),%st(1)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha204
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha204
fsubr %st(0),%st(1)
fldl -120(%edx)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(1),%st(0)
fldl -112(%edx)
fxch %st(1)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fsubr %st(0),%st(2)
faddp %st(0),%st(1)
fxch %st(4)
fstpl 96(%edx)
fxch %st(4)
fstpl 104(%edx)
fxch %st(1)
fstpl 112(%edx)
fstpl 120(%edx)
fxch %st(1)
fstpl -128(%ecx)
fstpl -120(%ecx)
fldl 40(%ecx)
fmul %st(0),%st(0)
fldl -32(%ecx)
fadd %st(0),%st(0)
fldl -24(%ecx)
fadd %st(0),%st(0)
fldl -16(%ecx)
fadd %st(0),%st(0)
fldl 24(%ecx)
fxch %st(4)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 40(%ecx)
fmul %st(4),%st(0)
fldl 32(%ecx)
fmul %st(4),%st(0)
faddp %st(0),%st(1)
fxch %st(4)
fstl 0(%esp)
fxch %st(3)
fstl 8(%esp)
fxch %st(3)
fmull 32(%ecx)
faddp %st(0),%st(1)
fldl 16(%ecx)
fxch %st(5)
fmul %st(0),%st(3)
fxch %st(3)
faddp %st(0),%st(1)
fxch %st(2)
fadd %st(0),%st(0)
fldl 24(%ecx)
fmul %st(2),%st(0)
faddp %st(0),%st(4)
fxch %st(1)
fstl 16(%esp)
fldl 8(%ecx)
fxch %st(5)
fmul %st(0),%st(1)
fxch %st(1)
faddp %st(0),%st(3)
fadd %st(0),%st(0)
fstpl 48(%esp)
fldl -8(%ecx)
fadd %st(0),%st(0)
fstl 24(%esp)
fldl 16(%ecx)
fmul %st(1),%st(0)
faddp %st(0),%st(4)
fmul %st(4),%st(0)
faddp %st(0),%st(2)
fxch %st(3)
fadd %st(0),%st(0)
fstpl 40(%esp)
fldl 0(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fsubr %st(0),%st(1)
fldl 8(%esp)
fldl 40(%ecx)
fmul %st(0),%st(1)
fldl 16(%esp)
fmul %st(0),%st(1)
fldl 32(%ecx)
fmul %st(0),%st(1)
fxch %st(1)
faddp %st(0),%st(3)
fldl 24(%esp)
fmul %st(0),%st(1)
fxch %st(1)
faddp %st(0),%st(2)
fldl 0(%ecx)
fadd %st(0),%st(0)
fstl 32(%esp)
fmull 8(%ecx)
faddp %st(0),%st(6)
fxch %st(3)
faddp %st(0),%st(5)
fldl crypto_scalarmult_curve25519_athlon_alpha255
fadd %st(5),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha255
fsubr %st(0),%st(5)
fldl 24(%ecx)
fmul %st(0),%st(4)
fxch %st(4)
faddp %st(0),%st(3)
fldl 32(%esp)
fmul %st(0),%st(4)
fxch %st(4)
faddp %st(0),%st(2)
fldl 16(%ecx)
fmul %st(0),%st(4)
fxch %st(4)
faddp %st(0),%st(3)
fxch %st(3)
fmull 40(%esp)
faddp %st(0),%st(1)
fxch %st(3)
fstpl -120(%edx)
fldl 8(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
fxch %st(2)
fmull crypto_scalarmult_curve25519_athlon_scale
fxch %st(3)
fstpl -112(%edx)
faddp %st(0),%st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 24(%esp)
fmull 40(%ecx)
fldl -32(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(2)
fldl 32(%esp)
fmull 32(%ecx)
faddp %st(0),%st(1)
fldl 0(%esp)
fmull -24(%ecx)
faddp %st(0),%st(3)
fldl 40(%esp)
fmull 24(%ecx)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha26
fadd %st(2),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha26
fsubr %st(0),%st(2)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha51
fadd %st(3),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha51
fsubr %st(0),%st(3)
fldl 16(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(2)
fxch %st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -16(%ecx)
faddp %st(0),%st(1)
fldl -24(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha77
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha77
fsubr %st(0),%st(1)
fxch %st(2)
fstpl -112(%ecx)
fldl 32(%esp)
fmull 40(%ecx)
fldl 40(%esp)
fmull 32(%ecx)
faddp %st(0),%st(1)
fldl 48(%esp)
fmull 24(%ecx)
faddp %st(0),%st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -8(%ecx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull -16(%ecx)
faddp %st(0),%st(1)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha102
fadd %st(2),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha102
fsubr %st(0),%st(2)
fxch %st(3)
fstpl -104(%ecx)
fldl 40(%esp)
fmull 40(%ecx)
fldl 48(%esp)
fmull 32(%ecx)
faddp %st(0),%st(1)
fldl 24(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull 0(%ecx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull -8(%ecx)
faddp %st(0),%st(1)
fldl -16(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha128
fadd %st(3),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha128
fsubr %st(0),%st(3)
fxch %st(1)
fstpl -96(%ecx)
fldl 48(%esp)
fldl 40(%ecx)
fmul %st(0),%st(1)
fmul %st(5),%st(0)
fxch %st(5)
fmull 32(%ecx)
faddp %st(0),%st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull 8(%ecx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull 0(%ecx)
faddp %st(0),%st(1)
fldl 16(%esp)
fmull -8(%ecx)
faddp %st(0),%st(1)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha153
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha153
fsubr %st(0),%st(1)
fxch %st(2)
fstpl -88(%ecx)
fldl 32(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(4)
fxch %st(3)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull 16(%ecx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull 8(%ecx)
faddp %st(0),%st(1)
fldl 16(%esp)
fmull 0(%ecx)
faddp %st(0),%st(1)
fldl -8(%ecx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha179
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha179
fsubr %st(0),%st(1)
fldl 32(%ecx)
fadd %st(0),%st(0)
fmull 40(%ecx)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull 24(%ecx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull 16(%ecx)
faddp %st(0),%st(1)
fldl 16(%esp)
fmull 8(%ecx)
faddp %st(0),%st(1)
fldl 24(%esp)
fmull 0(%ecx)
faddp %st(0),%st(1)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha204
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha204
fsubr %st(0),%st(1)
fldl -120(%edx)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(1),%st(0)
fldl -112(%edx)
fxch %st(1)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fsubr %st(0),%st(2)
faddp %st(0),%st(1)
fxch %st(4)
fstpl -80(%ecx)
fxch %st(4)
fstpl -72(%ecx)
fxch %st(1)
fstpl -64(%ecx)
fstpl -56(%ecx)
fxch %st(1)
fstpl -48(%ecx)
fstpl -40(%ecx)
fldl -40(%edx)
fldl 48(%ecx)
fadd %st(0),%st(1)
fsubl -40(%edx)
fxch %st(1)
fstpl -120(%edx)
fstpl -40(%edx)
fldl -32(%edx)
fldl 56(%ecx)
fadd %st(0),%st(1)
fsubl -32(%edx)
fxch %st(1)
fstpl -112(%edx)
fstpl -32(%edx)
fldl -104(%edx)
fldl -24(%edx)
fadd %st(0),%st(1)
fsubl -104(%edx)
fxch %st(1)
fstpl -104(%edx)
fstpl -24(%edx)
fldl -16(%edx)
fldl -96(%edx)
fadd %st(0),%st(1)
fsubl -16(%edx)
fxch %st(1)
fstpl -96(%edx)
fstpl -16(%edx)
fldl -8(%edx)
fldl -88(%edx)
fadd %st(0),%st(1)
fsubl -8(%edx)
fxch %st(1)
fstpl -88(%edx)
fstpl -8(%edx)
fldl 0(%edx)
fldl -80(%edx)
fadd %st(0),%st(1)
fsubl 0(%edx)
fxch %st(1)
fstpl -80(%edx)
fstpl 0(%edx)
fldl 8(%edx)
fldl -72(%edx)
fadd %st(0),%st(1)
fsubl 8(%edx)
fxch %st(1)
fstpl -72(%edx)
fstpl 8(%edx)
fldl 16(%edx)
fldl -64(%edx)
fadd %st(0),%st(1)
fsubl 16(%edx)
fxch %st(1)
fstpl -64(%edx)
fstpl 16(%edx)
fldl 24(%edx)
fldl -56(%edx)
fadd %st(0),%st(1)
fsubl 24(%edx)
fxch %st(1)
fstpl -56(%edx)
fstpl 24(%edx)
fldl 32(%edx)
fldl -48(%edx)
fadd %st(0),%st(1)
fsubl 32(%edx)
fxch %st(1)
fstpl -48(%edx)
fstpl 32(%edx)
fldl 64(%edx)
fsubl -112(%ecx)
fstpl -32(%ecx)
fldl 72(%edx)
fsubl -104(%ecx)
fstpl -24(%ecx)
fldl 80(%edx)
fsubl -96(%ecx)
fstpl -16(%ecx)
fldl 88(%edx)
fsubl -88(%ecx)
fstpl -8(%ecx)
fldl 96(%edx)
fsubl -80(%ecx)
fstpl 0(%ecx)
fldl 104(%edx)
fsubl -72(%ecx)
fstpl 8(%ecx)
fldl 112(%edx)
fsubl -64(%ecx)
fstpl 16(%ecx)
fldl 120(%edx)
fsubl -56(%ecx)
fstpl 24(%ecx)
fldl -128(%ecx)
fsubl -48(%ecx)
fstpl 32(%ecx)
fldl -120(%ecx)
fsubl -40(%ecx)
fstpl 40(%ecx)
fldl -48(%edx)
fmul %st(0),%st(0)
fldl -120(%edx)
fadd %st(0),%st(0)
fldl -112(%edx)
fadd %st(0),%st(0)
fldl -104(%edx)
fadd %st(0),%st(0)
fldl -64(%edx)
fxch %st(4)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -48(%edx)
fmul %st(4),%st(0)
fldl -56(%edx)
fmul %st(4),%st(0)
faddp %st(0),%st(1)
fxch %st(4)
fstl 0(%esp)
fxch %st(3)
fstl 8(%esp)
fxch %st(3)
fmull -56(%edx)
faddp %st(0),%st(1)
fldl -72(%edx)
fxch %st(5)
fmul %st(0),%st(3)
fxch %st(3)
faddp %st(0),%st(1)
fxch %st(2)
fadd %st(0),%st(0)
fldl -64(%edx)
fmul %st(2),%st(0)
faddp %st(0),%st(4)
fxch %st(1)
fstl 16(%esp)
fldl -80(%edx)
fxch %st(5)
fmul %st(0),%st(1)
fxch %st(1)
faddp %st(0),%st(3)
fadd %st(0),%st(0)
fstpl 48(%esp)
fldl -96(%edx)
fadd %st(0),%st(0)
fstl 24(%esp)
fldl -72(%edx)
fmul %st(1),%st(0)
faddp %st(0),%st(4)
fmul %st(4),%st(0)
faddp %st(0),%st(2)
fxch %st(3)
fadd %st(0),%st(0)
fstpl 40(%esp)
fldl -88(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fsubr %st(0),%st(1)
fldl 8(%esp)
fldl -48(%edx)
fmul %st(0),%st(1)
fldl 16(%esp)
fmul %st(0),%st(1)
fldl -56(%edx)
fmul %st(0),%st(1)
fxch %st(1)
faddp %st(0),%st(3)
fldl 24(%esp)
fmul %st(0),%st(1)
fxch %st(1)
faddp %st(0),%st(2)
fldl -88(%edx)
fadd %st(0),%st(0)
fstl 32(%esp)
fmull -80(%edx)
faddp %st(0),%st(6)
fxch %st(3)
faddp %st(0),%st(5)
fldl crypto_scalarmult_curve25519_athlon_alpha255
fadd %st(5),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha255
fsubr %st(0),%st(5)
fldl -64(%edx)
fmul %st(0),%st(4)
fxch %st(4)
faddp %st(0),%st(3)
fldl 32(%esp)
fmul %st(0),%st(4)
fxch %st(4)
faddp %st(0),%st(2)
fldl -72(%edx)
fmul %st(0),%st(4)
fxch %st(4)
faddp %st(0),%st(3)
fxch %st(3)
fmull 40(%esp)
faddp %st(0),%st(1)
fxch %st(3)
fstpl 48(%edx)
fldl -80(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
fxch %st(2)
fmull crypto_scalarmult_curve25519_athlon_scale
fxch %st(3)
fstpl 56(%edx)
faddp %st(0),%st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 24(%esp)
fmull -48(%edx)
fldl -120(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(2)
fldl 32(%esp)
fmull -56(%edx)
faddp %st(0),%st(1)
fldl 0(%esp)
fmull -112(%edx)
faddp %st(0),%st(3)
fldl 40(%esp)
fmull -64(%edx)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha26
fadd %st(2),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha26
fsubr %st(0),%st(2)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha51
fadd %st(3),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha51
fsubr %st(0),%st(3)
fldl -72(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(2)
fxch %st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -104(%edx)
faddp %st(0),%st(1)
fldl -112(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha77
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha77
fsubr %st(0),%st(1)
fxch %st(2)
fstpl -120(%edx)
fldl 32(%esp)
fmull -48(%edx)
fldl 40(%esp)
fmull -56(%edx)
faddp %st(0),%st(1)
fldl 48(%esp)
fmull -64(%edx)
faddp %st(0),%st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -96(%edx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull -104(%edx)
faddp %st(0),%st(1)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha102
fadd %st(2),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha102
fsubr %st(0),%st(2)
fxch %st(3)
fstpl -112(%edx)
fldl 40(%esp)
fmull -48(%edx)
fldl 48(%esp)
fmull -56(%edx)
faddp %st(0),%st(1)
fldl -64(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -88(%edx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull -96(%edx)
faddp %st(0),%st(1)
fldl -104(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha128
fadd %st(3),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha128
fsubr %st(0),%st(3)
fxch %st(1)
fstpl -104(%edx)
fldl 48(%esp)
fldl -48(%edx)
fmul %st(0),%st(1)
fmul %st(5),%st(0)
fxch %st(5)
fmull -56(%edx)
faddp %st(0),%st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -80(%edx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull -88(%edx)
faddp %st(0),%st(1)
fldl 16(%esp)
fmull -96(%edx)
faddp %st(0),%st(1)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha153
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha153
fsubr %st(0),%st(1)
fxch %st(2)
fstpl 40(%edx)
fldl -56(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(4)
fxch %st(3)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -72(%edx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull -80(%edx)
faddp %st(0),%st(1)
fldl 16(%esp)
fmull -88(%edx)
faddp %st(0),%st(1)
fldl -96(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha179
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha179
fsubr %st(0),%st(1)
fldl -56(%edx)
fadd %st(0),%st(0)
fmull -48(%edx)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -64(%edx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull -72(%edx)
faddp %st(0),%st(1)
fldl 16(%esp)
fmull -80(%edx)
faddp %st(0),%st(1)
fldl 24(%esp)
fmull -88(%edx)
faddp %st(0),%st(1)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha204
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha204
fsubr %st(0),%st(1)
fldl 48(%edx)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(1),%st(0)
fldl 56(%edx)
fxch %st(1)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fsubr %st(0),%st(2)
faddp %st(0),%st(1)
fxch %st(4)
fstpl -96(%edx)
fxch %st(4)
fstpl -88(%edx)
fxch %st(1)
fstpl -80(%edx)
fstpl -72(%edx)
fxch %st(1)
fstpl -64(%edx)
fstpl -56(%edx)
fldl 32(%edx)
fmul %st(0),%st(0)
fldl -40(%edx)
fadd %st(0),%st(0)
fldl -32(%edx)
fadd %st(0),%st(0)
fldl -24(%edx)
fadd %st(0),%st(0)
fldl 16(%edx)
fxch %st(4)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 32(%edx)
fmul %st(4),%st(0)
fldl 24(%edx)
fmul %st(4),%st(0)
faddp %st(0),%st(1)
fxch %st(4)
fstl 0(%esp)
fxch %st(3)
fstl 8(%esp)
fxch %st(3)
fmull 24(%edx)
faddp %st(0),%st(1)
fldl 8(%edx)
fxch %st(5)
fmul %st(0),%st(3)
fxch %st(3)
faddp %st(0),%st(1)
fxch %st(2)
fadd %st(0),%st(0)
fldl 16(%edx)
fmul %st(2),%st(0)
faddp %st(0),%st(4)
fxch %st(1)
fstl 16(%esp)
fldl 0(%edx)
fxch %st(5)
fmul %st(0),%st(1)
fxch %st(1)
faddp %st(0),%st(3)
fadd %st(0),%st(0)
fstpl 48(%esp)
fldl -16(%edx)
fadd %st(0),%st(0)
fstl 24(%esp)
fldl 8(%edx)
fmul %st(1),%st(0)
faddp %st(0),%st(4)
fmul %st(4),%st(0)
faddp %st(0),%st(2)
fxch %st(3)
fadd %st(0),%st(0)
fstpl 40(%esp)
fldl -8(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fsubr %st(0),%st(1)
fldl 8(%esp)
fldl 32(%edx)
fmul %st(0),%st(1)
fldl 16(%esp)
fmul %st(0),%st(1)
fldl 24(%edx)
fmul %st(0),%st(1)
fxch %st(1)
faddp %st(0),%st(3)
fldl 24(%esp)
fmul %st(0),%st(1)
fxch %st(1)
faddp %st(0),%st(2)
fldl -8(%edx)
fadd %st(0),%st(0)
fstl 32(%esp)
fmull 0(%edx)
faddp %st(0),%st(6)
fxch %st(3)
faddp %st(0),%st(5)
fldl crypto_scalarmult_curve25519_athlon_alpha255
fadd %st(5),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha255
fsubr %st(0),%st(5)
fldl 16(%edx)
fmul %st(0),%st(4)
fxch %st(4)
faddp %st(0),%st(3)
fldl 32(%esp)
fmul %st(0),%st(4)
fxch %st(4)
faddp %st(0),%st(2)
fldl 8(%edx)
fmul %st(0),%st(4)
fxch %st(4)
faddp %st(0),%st(3)
fxch %st(3)
fmull 40(%esp)
faddp %st(0),%st(1)
fxch %st(3)
fstpl -48(%edx)
fldl 0(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
fxch %st(2)
fmull crypto_scalarmult_curve25519_athlon_scale
fxch %st(3)
fstpl 48(%edx)
faddp %st(0),%st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 24(%esp)
fmull 32(%edx)
fldl -40(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(2)
fldl 32(%esp)
fmull 24(%edx)
faddp %st(0),%st(1)
fldl 0(%esp)
fmull -32(%edx)
faddp %st(0),%st(3)
fldl 40(%esp)
fmull 16(%edx)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha26
fadd %st(2),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha26
fsubr %st(0),%st(2)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha51
fadd %st(3),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha51
fsubr %st(0),%st(3)
fldl 8(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(2)
fxch %st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -24(%edx)
faddp %st(0),%st(1)
fldl -32(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha77
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha77
fsubr %st(0),%st(1)
fxch %st(2)
fstpl 56(%ecx)
fldl 32(%esp)
fmull 32(%edx)
fldl 40(%esp)
fmull 24(%edx)
faddp %st(0),%st(1)
fldl 48(%esp)
fmull 16(%edx)
faddp %st(0),%st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -16(%edx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull -24(%edx)
faddp %st(0),%st(1)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha102
fadd %st(2),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha102
fsubr %st(0),%st(2)
fxch %st(3)
fstpl 64(%ecx)
fldl 40(%esp)
fmull 32(%edx)
fldl 48(%esp)
fmull 24(%edx)
faddp %st(0),%st(1)
fldl 16(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull -8(%edx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull -16(%edx)
faddp %st(0),%st(1)
fldl -24(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha128
fadd %st(3),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha128
fsubr %st(0),%st(3)
fxch %st(1)
fstpl 72(%ecx)
fldl 48(%esp)
fldl 32(%edx)
fmul %st(0),%st(1)
fmul %st(5),%st(0)
fxch %st(5)
fmull 24(%edx)
faddp %st(0),%st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull 0(%edx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull -8(%edx)
faddp %st(0),%st(1)
fldl 16(%esp)
fmull -16(%edx)
faddp %st(0),%st(1)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha153
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha153
fsubr %st(0),%st(1)
fxch %st(2)
fstpl 80(%ecx)
fldl 24(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(4)
fxch %st(3)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull 8(%edx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull 0(%edx)
faddp %st(0),%st(1)
fldl 16(%esp)
fmull -8(%edx)
faddp %st(0),%st(1)
fldl -16(%edx)
fmul %st(0),%st(0)
faddp %st(0),%st(1)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha179
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha179
fsubr %st(0),%st(1)
fldl 24(%edx)
fadd %st(0),%st(0)
fmull 32(%edx)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%esp)
fmull 16(%edx)
faddp %st(0),%st(1)
fldl 8(%esp)
fmull 8(%edx)
faddp %st(0),%st(1)
fldl 16(%esp)
fmull 0(%edx)
faddp %st(0),%st(1)
fldl 24(%esp)
fmull -8(%edx)
faddp %st(0),%st(1)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha204
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha204
fsubr %st(0),%st(1)
fldl -48(%edx)
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(1),%st(0)
fldl 48(%edx)
fxch %st(1)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fsubr %st(0),%st(2)
faddp %st(0),%st(1)
fxch %st(4)
fstpl 88(%ecx)
fxch %st(4)
fstpl 96(%ecx)
fxch %st(1)
fstpl 104(%ecx)
fstpl 112(%ecx)
fxch %st(1)
fstpl 120(%ecx)
fstpl 128(%ecx)
fldl 32(%ecx)
fmull crypto_scalarmult_curve25519_athlon_121665
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fldl 40(%ecx)
fmull crypto_scalarmult_curve25519_athlon_121665
fadd %st(1),%st(0)
fxch %st(1)
fsubrp %st(0),%st(2)
fxch %st(1)
fstpl 0(%esp)
fldl crypto_scalarmult_curve25519_athlon_alpha255
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha255
fsubr %st(0),%st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fxch %st(1)
fstpl 8(%esp)
fldl -32(%ecx)
fmull crypto_scalarmult_curve25519_athlon_121665
faddp %st(0),%st(1)
fldl crypto_scalarmult_curve25519_athlon_alpha26
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha26
fldl -24(%ecx)
fmull crypto_scalarmult_curve25519_athlon_121665
fadd %st(1),%st(0)
fxch %st(1)
fsubrp %st(0),%st(2)
fxch %st(1)
fstpl -48(%edx)
fldl crypto_scalarmult_curve25519_athlon_alpha51
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha51
fldl -16(%ecx)
fmull crypto_scalarmult_curve25519_athlon_121665
fadd %st(1),%st(0)
fxch %st(1)
fsubrp %st(0),%st(2)
fxch %st(1)
fstpl -40(%edx)
fldl crypto_scalarmult_curve25519_athlon_alpha77
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha77
fldl -8(%ecx)
fmull crypto_scalarmult_curve25519_athlon_121665
fadd %st(1),%st(0)
fxch %st(1)
fsubrp %st(0),%st(2)
fxch %st(1)
fstpl -32(%edx)
fldl crypto_scalarmult_curve25519_athlon_alpha102
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha102
fldl 0(%ecx)
fmull crypto_scalarmult_curve25519_athlon_121665
fadd %st(1),%st(0)
fxch %st(1)
fsubrp %st(0),%st(2)
fxch %st(1)
fstpl -24(%edx)
fldl crypto_scalarmult_curve25519_athlon_alpha128
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha128
fldl 8(%ecx)
fmull crypto_scalarmult_curve25519_athlon_121665
fadd %st(1),%st(0)
fxch %st(1)
fsubrp %st(0),%st(2)
fxch %st(1)
fstpl -16(%edx)
fldl crypto_scalarmult_curve25519_athlon_alpha153
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha153
fldl 16(%ecx)
fmull crypto_scalarmult_curve25519_athlon_121665
fadd %st(1),%st(0)
fxch %st(1)
fsubrp %st(0),%st(2)
fxch %st(1)
fstpl -8(%edx)
fldl crypto_scalarmult_curve25519_athlon_alpha179
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha179
fldl 24(%ecx)
fmull crypto_scalarmult_curve25519_athlon_121665
fadd %st(1),%st(0)
fxch %st(1)
fsubrp %st(0),%st(2)
fxch %st(1)
fstpl 0(%edx)
fldl crypto_scalarmult_curve25519_athlon_alpha204
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha204
fldl 0(%esp)
fadd %st(1),%st(0)
fxch %st(1)
fsubrp %st(0),%st(2)
fxch %st(1)
fstpl 8(%edx)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fldl 8(%esp)
fadd %st(1),%st(0)
fxch %st(1)
fsubrp %st(0),%st(2)
fxch %st(1)
fstpl 16(%edx)
fstpl 48(%ecx)
fldl -120(%ecx)
fmull -40(%ecx)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 64(%edx)
fmull -48(%ecx)
faddp %st(0),%st(1)
fldl 72(%edx)
fmull -56(%ecx)
faddp %st(0),%st(1)
fldl 64(%edx)
fmull -40(%ecx)
fldl 80(%edx)
fmull -64(%ecx)
faddp %st(0),%st(2)
fldl 72(%edx)
fmull -48(%ecx)
faddp %st(0),%st(1)
fldl 88(%edx)
fmull -72(%ecx)
faddp %st(0),%st(2)
fldl 80(%edx)
fmull -56(%ecx)
faddp %st(0),%st(1)
fldl 96(%edx)
fmull -80(%ecx)
faddp %st(0),%st(2)
fldl 88(%edx)
fmull -64(%ecx)
faddp %st(0),%st(1)
fldl 72(%edx)
fmull -40(%ecx)
fldl 104(%edx)
fmull -88(%ecx)
faddp %st(0),%st(3)
fldl 96(%edx)
fmull -72(%ecx)
faddp %st(0),%st(2)
fldl 80(%edx)
fmull -48(%ecx)
faddp %st(0),%st(1)
fldl 112(%edx)
fmull -96(%ecx)
faddp %st(0),%st(3)
fldl 104(%edx)
fmull -80(%ecx)
faddp %st(0),%st(2)
fldl 88(%edx)
fmull -56(%ecx)
faddp %st(0),%st(1)
fldl 120(%edx)
fmull -104(%ecx)
faddp %st(0),%st(3)
fldl 112(%edx)
fmull -88(%ecx)
faddp %st(0),%st(2)
fldl 96(%edx)
fmull -64(%ecx)
faddp %st(0),%st(1)
fldl -128(%ecx)
fmull -112(%ecx)
faddp %st(0),%st(3)
fldl 120(%edx)
fmull -96(%ecx)
faddp %st(0),%st(2)
fldl 104(%edx)
fmull -72(%ecx)
faddp %st(0),%st(1)
fldl 80(%edx)
fmull -40(%ecx)
fldl 112(%edx)
fmull -80(%ecx)
faddp %st(0),%st(2)
fldl -128(%ecx)
fmull -104(%ecx)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(4),%st(0)
fldl 88(%edx)
fmull -48(%ecx)
faddp %st(0),%st(2)
fldl 120(%edx)
fmull -88(%ecx)
faddp %st(0),%st(3)
fldl -120(%ecx)
fmull -112(%ecx)
faddp %st(0),%st(4)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fldl 96(%edx)
fmull -56(%ecx)
faddp %st(0),%st(2)
fldl 88(%edx)
fmull -40(%ecx)
fldl -128(%ecx)
fmull -96(%ecx)
faddp %st(0),%st(4)
fxch %st(1)
fadd %st(0),%st(4)
fldl 104(%edx)
fmull -64(%ecx)
faddp %st(0),%st(3)
fldl 96(%edx)
fmull -48(%ecx)
faddp %st(0),%st(2)
fsubrp %st(0),%st(5)
fldl crypto_scalarmult_curve25519_athlon_alpha255
fadd %st(4),%st(0)
fldl 112(%edx)
fmull -72(%ecx)
faddp %st(0),%st(3)
fldl 104(%edx)
fmull -56(%ecx)
faddp %st(0),%st(2)
fldl -120(%ecx)
fmull -104(%ecx)
faddp %st(0),%st(4)
fsubl crypto_scalarmult_curve25519_athlon_alpha255
fldl 120(%edx)
fmull -80(%ecx)
faddp %st(0),%st(3)
fldl 96(%edx)
fmull -40(%ecx)
fldl 112(%edx)
fmull -64(%ecx)
faddp %st(0),%st(3)
fldl -128(%ecx)
fmull -88(%ecx)
faddp %st(0),%st(4)
fxch %st(1)
fadd %st(0),%st(4)
fsubrp %st(0),%st(5)
fxch %st(5)
fstpl 0(%esp)
fldl 104(%edx)
fmull -48(%ecx)
faddp %st(0),%st(5)
fldl 120(%edx)
fmull -72(%ecx)
faddp %st(0),%st(1)
fldl -120(%ecx)
fmull -96(%ecx)
faddp %st(0),%st(2)
fxch %st(2)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 112(%edx)
fmull -56(%ecx)
faddp %st(0),%st(5)
fldl -128(%ecx)
fmull -80(%ecx)
faddp %st(0),%st(3)
fxch %st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 64(%edx)
fmull -112(%ecx)
faddp %st(0),%st(2)
fxch %st(3)
fstpl 8(%esp)
fldl 104(%edx)
fmull -40(%ecx)
fldl 120(%edx)
fmull -64(%ecx)
faddp %st(0),%st(5)
fldl -120(%ecx)
fmull -88(%ecx)
faddp %st(0),%st(3)
fldl 64(%edx)
fmull -104(%ecx)
faddp %st(0),%st(4)
fldl crypto_scalarmult_curve25519_athlon_alpha26
fadd %st(2),%st(0)
fldl 112(%edx)
fmull -48(%ecx)
faddp %st(0),%st(2)
fldl -128(%ecx)
fmull -72(%ecx)
faddp %st(0),%st(6)
fxch %st(3)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 72(%edx)
fmull -112(%ecx)
faddp %st(0),%st(5)
fxch %st(3)
fsubl crypto_scalarmult_curve25519_athlon_alpha26
fldl 120(%edx)
fmull -56(%ecx)
faddp %st(0),%st(2)
fldl -120(%ecx)
fmull -80(%ecx)
faddp %st(0),%st(6)
fldl 64(%edx)
fmull -96(%ecx)
faddp %st(0),%st(4)
fadd %st(0),%st(4)
fsubrp %st(0),%st(2)
fldl 112(%edx)
fmull -40(%ecx)
fldl -128(%ecx)
fmull -64(%ecx)
faddp %st(0),%st(2)
fxch %st(5)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 72(%edx)
fmull -104(%ecx)
faddp %st(0),%st(4)
fldl crypto_scalarmult_curve25519_athlon_alpha51
fadd %st(5),%st(0)
fldl 120(%edx)
fmull -48(%ecx)
faddp %st(0),%st(7)
fldl -120(%ecx)
fmull -72(%ecx)
faddp %st(0),%st(3)
fldl 64(%edx)
fmull -88(%ecx)
faddp %st(0),%st(2)
fldl 80(%edx)
fmull -112(%ecx)
faddp %st(0),%st(5)
fsubl crypto_scalarmult_curve25519_athlon_alpha51
fxch %st(3)
fstpl 16(%esp)
fldl -128(%ecx)
fmull -56(%ecx)
faddp %st(0),%st(6)
fxch %st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 72(%edx)
fmull -96(%ecx)
faddp %st(0),%st(2)
fxch %st(2)
fadd %st(0),%st(3)
fsubrp %st(0),%st(4)
fldl 120(%edx)
fmull -40(%ecx)
fldl -120(%ecx)
fmull -64(%ecx)
faddp %st(0),%st(6)
fldl 64(%edx)
fmull -80(%ecx)
faddp %st(0),%st(3)
fldl 80(%edx)
fmull -104(%ecx)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha77
fadd %st(4),%st(0)
fldl -128(%ecx)
fmull -48(%ecx)
faddp %st(0),%st(2)
fxch %st(6)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 72(%edx)
fmull -88(%ecx)
faddp %st(0),%st(4)
fldl 88(%edx)
fmull -112(%ecx)
faddp %st(0),%st(3)
fxch %st(6)
fsubl crypto_scalarmult_curve25519_athlon_alpha77
fxch %st(5)
fstpl 24(%esp)
fldl -120(%ecx)
fmull -56(%ecx)
faddp %st(0),%st(1)
fldl 64(%edx)
fmull -72(%ecx)
faddp %st(0),%st(6)
fldl 80(%edx)
fmull -96(%ecx)
faddp %st(0),%st(3)
fxch %st(4)
fadd %st(0),%st(1)
fsubrp %st(0),%st(3)
fldl -128(%ecx)
fmull -40(%ecx)
fxch %st(4)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 72(%edx)
fmull -80(%ecx)
faddp %st(0),%st(6)
fldl 88(%edx)
fmull -104(%ecx)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha102
fadd %st(2),%st(0)
fldl -120(%ecx)
fmull -48(%ecx)
faddp %st(0),%st(6)
fldl 64(%edx)
fmull -64(%ecx)
faddp %st(0),%st(2)
fldl 80(%edx)
fmull -88(%ecx)
faddp %st(0),%st(7)
fldl 96(%edx)
fmull -112(%ecx)
faddp %st(0),%st(4)
fsubl crypto_scalarmult_curve25519_athlon_alpha102
fxch %st(4)
fstpl 32(%esp)
fxch %st(4)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 72(%edx)
fmull -72(%ecx)
faddp %st(0),%st(5)
fldl 88(%edx)
fmull -96(%ecx)
faddp %st(0),%st(6)
fxch %st(3)
fadd %st(0),%st(2)
fsubrp %st(0),%st(1)
fldl 64(%edx)
fmull -56(%ecx)
faddp %st(0),%st(3)
fldl 80(%edx)
fmull -80(%ecx)
faddp %st(0),%st(4)
fldl 96(%edx)
fmull -104(%ecx)
faddp %st(0),%st(5)
fldl crypto_scalarmult_curve25519_athlon_alpha128
fadd %st(2),%st(0)
fldl 72(%edx)
fmull -64(%ecx)
faddp %st(0),%st(4)
fldl 88(%edx)
fmull -88(%ecx)
faddp %st(0),%st(5)
fldl 104(%edx)
fmull -112(%ecx)
faddp %st(0),%st(6)
fsubl crypto_scalarmult_curve25519_athlon_alpha128
fxch %st(1)
fstpl 40(%esp)
fldl 80(%edx)
fmull -72(%ecx)
faddp %st(0),%st(3)
fldl 96(%edx)
fmull -96(%ecx)
faddp %st(0),%st(4)
fadd %st(0),%st(4)
fsubrp %st(0),%st(1)
fstpl 48(%esp)
fldl 88(%edx)
fmull -80(%ecx)
faddp %st(0),%st(1)
fldl 104(%edx)
fmull -104(%ecx)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha153
fadd %st(3),%st(0)
fldl 96(%edx)
fmull -88(%ecx)
faddp %st(0),%st(2)
fldl 112(%edx)
fmull -112(%ecx)
faddp %st(0),%st(3)
fsubl crypto_scalarmult_curve25519_athlon_alpha153
fldl 104(%edx)
fmull -96(%ecx)
faddp %st(0),%st(2)
fadd %st(0),%st(2)
fsubrp %st(0),%st(3)
fxch %st(2)
fstpl 24(%edx)
fldl 112(%edx)
fmull -104(%ecx)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha179
fadd %st(1),%st(0)
fldl 120(%edx)
fmull -112(%ecx)
faddp %st(0),%st(3)
fsubl crypto_scalarmult_curve25519_athlon_alpha179
fldl 0(%esp)
fldl 8(%esp)
fxch %st(2)
fadd %st(0),%st(4)
fsubrp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha204
fadd %st(4),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha204
fadd %st(0),%st(1)
fsubrp %st(0),%st(4)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fsubr %st(0),%st(1)
faddp %st(0),%st(2)
fxch %st(2)
fstpl 32(%edx)
fxch %st(2)
fstpl 48(%edx)
fstpl 56(%edx)
fstpl -112(%ecx)
fldl -48(%edx)
faddl 64(%edx)
fstpl -104(%ecx)
fldl -40(%edx)
faddl 72(%edx)
fstpl -96(%ecx)
fldl -32(%edx)
faddl 80(%edx)
fstpl -88(%ecx)
fldl -24(%edx)
faddl 88(%edx)
fstpl -80(%ecx)
fldl -16(%edx)
faddl 96(%edx)
fstpl -16(%edx)
fldl -8(%edx)
faddl 104(%edx)
fstpl -8(%edx)
fldl 0(%edx)
faddl 112(%edx)
fstpl 0(%edx)
fldl 8(%edx)
faddl 120(%edx)
fstpl 8(%edx)
fldl 16(%edx)
faddl -128(%ecx)
fstpl 16(%edx)
fldl 48(%ecx)
faddl -120(%ecx)
fstpl 80(%edx)
fldl 128(%ecx)
fmull -128(%edx)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 56(%ecx)
fmull 120(%esp)
faddp %st(0),%st(1)
fldl 64(%ecx)
fmull 112(%esp)
faddp %st(0),%st(1)
fldl 56(%ecx)
fmull -128(%edx)
fldl 72(%ecx)
fmull 104(%esp)
faddp %st(0),%st(2)
fldl 64(%ecx)
fmull 120(%esp)
faddp %st(0),%st(1)
fldl 80(%ecx)
fmull 96(%esp)
faddp %st(0),%st(2)
fldl 72(%ecx)
fmull 112(%esp)
faddp %st(0),%st(1)
fldl 88(%ecx)
fmull 88(%esp)
faddp %st(0),%st(2)
fldl 80(%ecx)
fmull 104(%esp)
faddp %st(0),%st(1)
fldl 64(%ecx)
fmull -128(%edx)
fldl 96(%ecx)
fmull 80(%esp)
faddp %st(0),%st(3)
fldl 88(%ecx)
fmull 96(%esp)
faddp %st(0),%st(2)
fldl 72(%ecx)
fmull 120(%esp)
faddp %st(0),%st(1)
fldl 104(%ecx)
fmull 72(%esp)
faddp %st(0),%st(3)
fldl 96(%ecx)
fmull 88(%esp)
faddp %st(0),%st(2)
fldl 80(%ecx)
fmull 112(%esp)
faddp %st(0),%st(1)
fldl 112(%ecx)
fmull 64(%esp)
faddp %st(0),%st(3)
fldl 104(%ecx)
fmull 80(%esp)
faddp %st(0),%st(2)
fldl 88(%ecx)
fmull 104(%esp)
faddp %st(0),%st(1)
fldl 120(%ecx)
fmull 56(%esp)
faddp %st(0),%st(3)
fldl 112(%ecx)
fmull 72(%esp)
faddp %st(0),%st(2)
fldl 96(%ecx)
fmull 96(%esp)
faddp %st(0),%st(1)
fldl 72(%ecx)
fmull -128(%edx)
fldl 104(%ecx)
fmull 88(%esp)
faddp %st(0),%st(2)
fldl 120(%ecx)
fmull 64(%esp)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(4),%st(0)
fldl 80(%ecx)
fmull 120(%esp)
faddp %st(0),%st(2)
fldl 112(%ecx)
fmull 80(%esp)
faddp %st(0),%st(3)
fldl 128(%ecx)
fmull 56(%esp)
faddp %st(0),%st(4)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fldl 88(%ecx)
fmull 112(%esp)
faddp %st(0),%st(2)
fldl 80(%ecx)
fmull -128(%edx)
fldl 120(%ecx)
fmull 72(%esp)
faddp %st(0),%st(4)
fxch %st(1)
fadd %st(0),%st(4)
fldl 96(%ecx)
fmull 104(%esp)
faddp %st(0),%st(3)
fldl 88(%ecx)
fmull 120(%esp)
faddp %st(0),%st(2)
fsubrp %st(0),%st(5)
fldl crypto_scalarmult_curve25519_athlon_alpha255
fadd %st(4),%st(0)
fldl 104(%ecx)
fmull 96(%esp)
faddp %st(0),%st(3)
fldl 96(%ecx)
fmull 112(%esp)
faddp %st(0),%st(2)
fldl 128(%ecx)
fmull 64(%esp)
faddp %st(0),%st(4)
fsubl crypto_scalarmult_curve25519_athlon_alpha255
fldl 112(%ecx)
fmull 88(%esp)
faddp %st(0),%st(3)
fldl 88(%ecx)
fmull -128(%edx)
fldl 104(%ecx)
fmull 104(%esp)
faddp %st(0),%st(3)
fldl 120(%ecx)
fmull 80(%esp)
faddp %st(0),%st(4)
fxch %st(1)
fadd %st(0),%st(4)
fsubrp %st(0),%st(5)
fxch %st(5)
fstpl 0(%esp)
fldl 96(%ecx)
fmull 120(%esp)
faddp %st(0),%st(5)
fldl 112(%ecx)
fmull 96(%esp)
faddp %st(0),%st(1)
fldl 128(%ecx)
fmull 72(%esp)
faddp %st(0),%st(2)
fxch %st(2)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 104(%ecx)
fmull 112(%esp)
faddp %st(0),%st(5)
fldl 120(%ecx)
fmull 88(%esp)
faddp %st(0),%st(3)
fxch %st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 56(%ecx)
fmull 56(%esp)
faddp %st(0),%st(2)
fxch %st(3)
fstpl 8(%esp)
fldl 96(%ecx)
fmull -128(%edx)
fldl 112(%ecx)
fmull 104(%esp)
faddp %st(0),%st(5)
fldl 128(%ecx)
fmull 80(%esp)
faddp %st(0),%st(3)
fldl 56(%ecx)
fmull 64(%esp)
faddp %st(0),%st(4)
fldl crypto_scalarmult_curve25519_athlon_alpha26
fadd %st(2),%st(0)
fldl 104(%ecx)
fmull 120(%esp)
faddp %st(0),%st(2)
fldl 120(%ecx)
fmull 96(%esp)
faddp %st(0),%st(6)
fxch %st(3)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 64(%ecx)
fmull 56(%esp)
faddp %st(0),%st(5)
fxch %st(3)
fsubl crypto_scalarmult_curve25519_athlon_alpha26
fldl 112(%ecx)
fmull 112(%esp)
faddp %st(0),%st(2)
fldl 128(%ecx)
fmull 88(%esp)
faddp %st(0),%st(6)
fldl 56(%ecx)
fmull 72(%esp)
faddp %st(0),%st(4)
fadd %st(0),%st(4)
fsubrp %st(0),%st(2)
fldl 104(%ecx)
fmull -128(%edx)
fldl 120(%ecx)
fmull 104(%esp)
faddp %st(0),%st(2)
fxch %st(5)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 64(%ecx)
fmull 64(%esp)
faddp %st(0),%st(4)
fldl crypto_scalarmult_curve25519_athlon_alpha51
fadd %st(5),%st(0)
fldl 112(%ecx)
fmull 120(%esp)
faddp %st(0),%st(7)
fldl 128(%ecx)
fmull 96(%esp)
faddp %st(0),%st(3)
fldl 56(%ecx)
fmull 80(%esp)
faddp %st(0),%st(2)
fldl 72(%ecx)
fmull 56(%esp)
faddp %st(0),%st(5)
fsubl crypto_scalarmult_curve25519_athlon_alpha51
fxch %st(3)
fstpl -48(%edx)
fldl 120(%ecx)
fmull 112(%esp)
faddp %st(0),%st(6)
fxch %st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 64(%ecx)
fmull 72(%esp)
faddp %st(0),%st(2)
fxch %st(2)
fadd %st(0),%st(3)
fsubrp %st(0),%st(4)
fldl 112(%ecx)
fmull -128(%edx)
fldl 128(%ecx)
fmull 104(%esp)
faddp %st(0),%st(6)
fldl 56(%ecx)
fmull 88(%esp)
faddp %st(0),%st(3)
fldl 72(%ecx)
fmull 64(%esp)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha77
fadd %st(4),%st(0)
fldl 120(%ecx)
fmull 120(%esp)
faddp %st(0),%st(2)
fxch %st(6)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 64(%ecx)
fmull 80(%esp)
faddp %st(0),%st(4)
fldl 80(%ecx)
fmull 56(%esp)
faddp %st(0),%st(3)
fxch %st(6)
fsubl crypto_scalarmult_curve25519_athlon_alpha77
fxch %st(5)
fstpl -40(%edx)
fldl 128(%ecx)
fmull 112(%esp)
faddp %st(0),%st(1)
fldl 56(%ecx)
fmull 96(%esp)
faddp %st(0),%st(6)
fldl 72(%ecx)
fmull 72(%esp)
faddp %st(0),%st(3)
fxch %st(4)
fadd %st(0),%st(1)
fsubrp %st(0),%st(3)
fldl 120(%ecx)
fmull -128(%edx)
fxch %st(4)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 64(%ecx)
fmull 88(%esp)
faddp %st(0),%st(6)
fldl 80(%ecx)
fmull 64(%esp)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha102
fadd %st(2),%st(0)
fldl 128(%ecx)
fmull 120(%esp)
faddp %st(0),%st(6)
fldl 56(%ecx)
fmull 104(%esp)
faddp %st(0),%st(2)
fldl 72(%ecx)
fmull 80(%esp)
faddp %st(0),%st(7)
fldl 88(%ecx)
fmull 56(%esp)
faddp %st(0),%st(4)
fsubl crypto_scalarmult_curve25519_athlon_alpha102
fxch %st(4)
fstpl -32(%edx)
fxch %st(4)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 64(%ecx)
fmull 96(%esp)
faddp %st(0),%st(5)
fldl 80(%ecx)
fmull 72(%esp)
faddp %st(0),%st(6)
fxch %st(3)
fadd %st(0),%st(2)
fsubrp %st(0),%st(1)
fldl 56(%ecx)
fmull 112(%esp)
faddp %st(0),%st(3)
fldl 72(%ecx)
fmull 88(%esp)
faddp %st(0),%st(4)
fldl 88(%ecx)
fmull 64(%esp)
faddp %st(0),%st(5)
fldl crypto_scalarmult_curve25519_athlon_alpha128
fadd %st(2),%st(0)
fldl 64(%ecx)
fmull 104(%esp)
faddp %st(0),%st(4)
fldl 80(%ecx)
fmull 80(%esp)
faddp %st(0),%st(5)
fldl 96(%ecx)
fmull 56(%esp)
faddp %st(0),%st(6)
fsubl crypto_scalarmult_curve25519_athlon_alpha128
fxch %st(1)
fstpl -24(%edx)
fldl 72(%ecx)
fmull 96(%esp)
faddp %st(0),%st(3)
fldl 88(%ecx)
fmull 72(%esp)
faddp %st(0),%st(4)
fadd %st(0),%st(4)
fsubrp %st(0),%st(1)
fstpl 96(%edx)
fldl 80(%ecx)
fmull 88(%esp)
faddp %st(0),%st(1)
fldl 96(%ecx)
fmull 64(%esp)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha153
fadd %st(3),%st(0)
fldl 88(%ecx)
fmull 80(%esp)
faddp %st(0),%st(2)
fldl 104(%ecx)
fmull 56(%esp)
faddp %st(0),%st(3)
fsubl crypto_scalarmult_curve25519_athlon_alpha153
fldl 96(%ecx)
fmull 72(%esp)
faddp %st(0),%st(2)
fadd %st(0),%st(2)
fsubrp %st(0),%st(3)
fxch %st(2)
fstpl 104(%edx)
fldl 104(%ecx)
fmull 64(%esp)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha179
fadd %st(1),%st(0)
fldl 112(%ecx)
fmull 56(%esp)
faddp %st(0),%st(3)
fsubl crypto_scalarmult_curve25519_athlon_alpha179
fldl 0(%esp)
fldl 8(%esp)
fxch %st(2)
fadd %st(0),%st(4)
fsubrp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha204
fadd %st(4),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha204
fadd %st(0),%st(1)
fsubrp %st(0),%st(4)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fsubr %st(0),%st(1)
faddp %st(0),%st(2)
fxch %st(2)
fstpl 112(%edx)
fxch %st(2)
fstpl 120(%edx)
fstpl -128(%ecx)
fstpl -120(%ecx)
fldl 80(%edx)
fmull 40(%ecx)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -104(%ecx)
fmull 32(%ecx)
faddp %st(0),%st(1)
fldl -96(%ecx)
fmull 24(%ecx)
faddp %st(0),%st(1)
fldl -104(%ecx)
fmull 40(%ecx)
fldl -88(%ecx)
fmull 16(%ecx)
faddp %st(0),%st(2)
fldl -96(%ecx)
fmull 32(%ecx)
faddp %st(0),%st(1)
fldl -80(%ecx)
fmull 8(%ecx)
faddp %st(0),%st(2)
fldl -88(%ecx)
fmull 24(%ecx)
faddp %st(0),%st(1)
fldl -16(%edx)
fmull 0(%ecx)
faddp %st(0),%st(2)
fldl -80(%ecx)
fmull 16(%ecx)
faddp %st(0),%st(1)
fldl -96(%ecx)
fmull 40(%ecx)
fldl -8(%edx)
fmull -8(%ecx)
faddp %st(0),%st(3)
fldl -16(%edx)
fmull 8(%ecx)
faddp %st(0),%st(2)
fldl -88(%ecx)
fmull 32(%ecx)
faddp %st(0),%st(1)
fldl 0(%edx)
fmull -16(%ecx)
faddp %st(0),%st(3)
fldl -8(%edx)
fmull 0(%ecx)
faddp %st(0),%st(2)
fldl -80(%ecx)
fmull 24(%ecx)
faddp %st(0),%st(1)
fldl 8(%edx)
fmull -24(%ecx)
faddp %st(0),%st(3)
fldl 0(%edx)
fmull -8(%ecx)
faddp %st(0),%st(2)
fldl -16(%edx)
fmull 16(%ecx)
faddp %st(0),%st(1)
fldl 16(%edx)
fmull -32(%ecx)
faddp %st(0),%st(3)
fldl 8(%edx)
fmull -16(%ecx)
faddp %st(0),%st(2)
fldl -8(%edx)
fmull 8(%ecx)
faddp %st(0),%st(1)
fldl -88(%ecx)
fmull 40(%ecx)
fldl 0(%edx)
fmull 0(%ecx)
faddp %st(0),%st(2)
fldl 16(%edx)
fmull -24(%ecx)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(4),%st(0)
fldl -80(%ecx)
fmull 32(%ecx)
faddp %st(0),%st(2)
fldl 8(%edx)
fmull -8(%ecx)
faddp %st(0),%st(3)
fldl 80(%edx)
fmull -32(%ecx)
faddp %st(0),%st(4)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fldl -16(%edx)
fmull 24(%ecx)
faddp %st(0),%st(2)
fldl -80(%ecx)
fmull 40(%ecx)
fldl 16(%edx)
fmull -16(%ecx)
faddp %st(0),%st(4)
fxch %st(1)
fadd %st(0),%st(4)
fldl -8(%edx)
fmull 16(%ecx)
faddp %st(0),%st(3)
fldl -16(%edx)
fmull 32(%ecx)
faddp %st(0),%st(2)
fsubrp %st(0),%st(5)
fldl crypto_scalarmult_curve25519_athlon_alpha255
fadd %st(4),%st(0)
fldl 0(%edx)
fmull 8(%ecx)
faddp %st(0),%st(3)
fldl -8(%edx)
fmull 24(%ecx)
faddp %st(0),%st(2)
fldl 80(%edx)
fmull -24(%ecx)
faddp %st(0),%st(4)
fsubl crypto_scalarmult_curve25519_athlon_alpha255
fldl 8(%edx)
fmull 0(%ecx)
faddp %st(0),%st(3)
fldl -16(%edx)
fmull 40(%ecx)
fldl 0(%edx)
fmull 16(%ecx)
faddp %st(0),%st(3)
fldl 16(%edx)
fmull -8(%ecx)
faddp %st(0),%st(4)
fxch %st(1)
fadd %st(0),%st(4)
fsubrp %st(0),%st(5)
fxch %st(5)
fstpl 0(%esp)
fldl -8(%edx)
fmull 32(%ecx)
faddp %st(0),%st(5)
fldl 8(%edx)
fmull 8(%ecx)
faddp %st(0),%st(1)
fldl 80(%edx)
fmull -16(%ecx)
faddp %st(0),%st(2)
fxch %st(2)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl 0(%edx)
fmull 24(%ecx)
faddp %st(0),%st(5)
fldl 16(%edx)
fmull 0(%ecx)
faddp %st(0),%st(3)
fxch %st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -104(%ecx)
fmull -32(%ecx)
faddp %st(0),%st(2)
fxch %st(3)
fstpl 8(%esp)
fldl -8(%edx)
fmull 40(%ecx)
fldl 8(%edx)
fmull 16(%ecx)
faddp %st(0),%st(5)
fldl 80(%edx)
fmull -8(%ecx)
faddp %st(0),%st(3)
fldl -104(%ecx)
fmull -24(%ecx)
faddp %st(0),%st(4)
fldl crypto_scalarmult_curve25519_athlon_alpha26
fadd %st(2),%st(0)
fldl 0(%edx)
fmull 32(%ecx)
faddp %st(0),%st(2)
fldl 16(%edx)
fmull 8(%ecx)
faddp %st(0),%st(6)
fxch %st(3)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -96(%ecx)
fmull -32(%ecx)
faddp %st(0),%st(5)
fxch %st(3)
fsubl crypto_scalarmult_curve25519_athlon_alpha26
fldl 8(%edx)
fmull 24(%ecx)
faddp %st(0),%st(2)
fldl 80(%edx)
fmull 0(%ecx)
faddp %st(0),%st(6)
fldl -104(%ecx)
fmull -16(%ecx)
faddp %st(0),%st(4)
fadd %st(0),%st(4)
fsubrp %st(0),%st(2)
fldl 0(%edx)
fmull 40(%ecx)
fldl 16(%edx)
fmull 16(%ecx)
faddp %st(0),%st(2)
fxch %st(5)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -96(%ecx)
fmull -24(%ecx)
faddp %st(0),%st(4)
fldl crypto_scalarmult_curve25519_athlon_alpha51
fadd %st(5),%st(0)
fldl 8(%edx)
fmull 32(%ecx)
faddp %st(0),%st(7)
fldl 80(%edx)
fmull 8(%ecx)
faddp %st(0),%st(3)
fldl -104(%ecx)
fmull -8(%ecx)
faddp %st(0),%st(2)
fldl -88(%ecx)
fmull -32(%ecx)
faddp %st(0),%st(5)
fsubl crypto_scalarmult_curve25519_athlon_alpha51
fxch %st(3)
fstpl 64(%edx)
fldl 16(%edx)
fmull 24(%ecx)
faddp %st(0),%st(6)
fxch %st(1)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -96(%ecx)
fmull -16(%ecx)
faddp %st(0),%st(2)
fxch %st(2)
fadd %st(0),%st(3)
fsubrp %st(0),%st(4)
fldl 8(%edx)
fmull 40(%ecx)
fldl 80(%edx)
fmull 16(%ecx)
faddp %st(0),%st(6)
fldl -104(%ecx)
fmull 0(%ecx)
faddp %st(0),%st(3)
fldl -88(%ecx)
fmull -24(%ecx)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha77
fadd %st(4),%st(0)
fldl 16(%edx)
fmull 32(%ecx)
faddp %st(0),%st(2)
fxch %st(6)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -96(%ecx)
fmull -8(%ecx)
faddp %st(0),%st(4)
fldl -80(%ecx)
fmull -32(%ecx)
faddp %st(0),%st(3)
fxch %st(6)
fsubl crypto_scalarmult_curve25519_athlon_alpha77
fxch %st(5)
fstpl 72(%edx)
fldl 80(%edx)
fmull 24(%ecx)
faddp %st(0),%st(1)
fldl -104(%ecx)
fmull 8(%ecx)
faddp %st(0),%st(6)
fldl -88(%ecx)
fmull -16(%ecx)
faddp %st(0),%st(3)
fxch %st(4)
fadd %st(0),%st(1)
fsubrp %st(0),%st(3)
fldl 16(%edx)
fmull 40(%ecx)
fxch %st(4)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -96(%ecx)
fmull 0(%ecx)
faddp %st(0),%st(6)
fldl -80(%ecx)
fmull -24(%ecx)
faddp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha102
fadd %st(2),%st(0)
fldl 80(%edx)
fmull 32(%ecx)
faddp %st(0),%st(6)
fldl -104(%ecx)
fmull 16(%ecx)
faddp %st(0),%st(2)
fldl -88(%ecx)
fmull -8(%ecx)
faddp %st(0),%st(7)
fldl -16(%edx)
fmull -32(%ecx)
faddp %st(0),%st(4)
fsubl crypto_scalarmult_curve25519_athlon_alpha102
fxch %st(4)
fstpl 80(%edx)
fxch %st(4)
fmull crypto_scalarmult_curve25519_athlon_scale
fldl -96(%ecx)
fmull 8(%ecx)
faddp %st(0),%st(5)
fldl -80(%ecx)
fmull -16(%ecx)
faddp %st(0),%st(6)
fxch %st(3)
fadd %st(0),%st(2)
fsubrp %st(0),%st(1)
fldl -104(%ecx)
fmull 24(%ecx)
faddp %st(0),%st(3)
fldl -88(%ecx)
fmull 0(%ecx)
faddp %st(0),%st(4)
fldl -16(%edx)
fmull -24(%ecx)
faddp %st(0),%st(5)
fldl crypto_scalarmult_curve25519_athlon_alpha128
fadd %st(2),%st(0)
fldl -96(%ecx)
fmull 16(%ecx)
faddp %st(0),%st(4)
fldl -80(%ecx)
fmull -8(%ecx)
faddp %st(0),%st(5)
fldl -8(%edx)
fmull -32(%ecx)
faddp %st(0),%st(6)
fsubl crypto_scalarmult_curve25519_athlon_alpha128
fxch %st(1)
fstpl 88(%edx)
fldl -88(%ecx)
fmull 8(%ecx)
faddp %st(0),%st(3)
fldl -16(%edx)
fmull -16(%ecx)
faddp %st(0),%st(4)
fadd %st(0),%st(4)
fsubrp %st(0),%st(1)
fstpl -104(%ecx)
fldl -80(%ecx)
fmull 0(%ecx)
faddp %st(0),%st(1)
fldl -8(%edx)
fmull -24(%ecx)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha153
fadd %st(3),%st(0)
fldl -16(%edx)
fmull -8(%ecx)
faddp %st(0),%st(2)
fldl 0(%edx)
fmull -32(%ecx)
faddp %st(0),%st(3)
fsubl crypto_scalarmult_curve25519_athlon_alpha153
fldl -8(%edx)
fmull -16(%ecx)
faddp %st(0),%st(2)
fadd %st(0),%st(2)
fsubrp %st(0),%st(3)
fxch %st(2)
fstpl -96(%ecx)
fldl 0(%edx)
fmull -24(%ecx)
faddp %st(0),%st(2)
fldl crypto_scalarmult_curve25519_athlon_alpha179
fadd %st(1),%st(0)
fldl 8(%edx)
fmull -32(%ecx)
faddp %st(0),%st(3)
fsubl crypto_scalarmult_curve25519_athlon_alpha179
fldl 0(%esp)
fldl 8(%esp)
fxch %st(2)
fadd %st(0),%st(4)
fsubrp %st(0),%st(3)
fldl crypto_scalarmult_curve25519_athlon_alpha204
fadd %st(4),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha204
fadd %st(0),%st(1)
fsubrp %st(0),%st(4)
fldl crypto_scalarmult_curve25519_athlon_alpha230
fadd %st(1),%st(0)
fsubl crypto_scalarmult_curve25519_athlon_alpha230
fsubr %st(0),%st(1)
faddp %st(0),%st(2)
fxch %st(2)
fstpl -88(%ecx)
fxch %st(2)
fstpl -80(%ecx)
fstpl -72(%ecx)
fstpl -64(%ecx)
fldl 136(%ecx)
fldl -120(%edx)
fldl 16(%esp)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl 16(%esp)
fxch %st(1)
fstpl -16(%edx)
fstpl 0(%esp)
fldl -112(%edx)
fldl 24(%esp)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl 24(%esp)
fxch %st(1)
fstpl -8(%edx)
fstpl 8(%esp)
fldl -104(%edx)
fldl 32(%esp)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl 32(%esp)
fxch %st(1)
fstpl 0(%edx)
fstpl 16(%esp)
fldl 40(%edx)
fldl 40(%esp)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl 40(%esp)
fxch %st(1)
fstpl 8(%edx)
fstpl 24(%esp)
fldl -96(%edx)
fldl 48(%esp)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl 48(%esp)
fxch %st(1)
fstpl 16(%edx)
fstpl 32(%esp)
fldl -88(%edx)
fldl 24(%edx)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl 24(%edx)
fxch %st(1)
fstpl 24(%edx)
fstpl 40(%esp)
fldl -80(%edx)
fldl 32(%edx)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl 32(%edx)
fxch %st(1)
fstpl 32(%edx)
fstpl 48(%esp)
fldl -72(%edx)
fldl 48(%edx)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl 48(%edx)
fxch %st(1)
fstpl 40(%edx)
fstpl -120(%edx)
fldl -64(%edx)
fldl 56(%edx)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl 56(%edx)
fxch %st(1)
fstpl 48(%edx)
fstpl -112(%edx)
fldl -56(%edx)
fldl -112(%ecx)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl -112(%ecx)
fxch %st(1)
fstpl 56(%edx)
fstpl -104(%edx)
fldl -48(%edx)
fldl 64(%edx)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl 64(%edx)
fxch %st(1)
fstpl 64(%edx)
fstpl -96(%edx)
fldl -40(%edx)
fldl 72(%edx)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl 72(%edx)
fxch %st(1)
fstpl 72(%edx)
fstpl -88(%edx)
fldl -32(%edx)
fldl 80(%edx)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl 80(%edx)
fxch %st(1)
fstpl 80(%edx)
fstpl -80(%edx)
fldl -24(%edx)
fldl 88(%edx)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl 88(%edx)
fxch %st(1)
fstpl 88(%edx)
fstpl -72(%edx)
fldl 96(%edx)
fldl -104(%ecx)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl -104(%ecx)
fxch %st(1)
fstpl 96(%edx)
fstpl -64(%edx)
fldl 104(%edx)
fldl -96(%ecx)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl -96(%ecx)
fxch %st(1)
fstpl 104(%edx)
fstpl -56(%edx)
fldl 112(%edx)
fldl -88(%ecx)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl -88(%ecx)
fxch %st(1)
fstpl 112(%edx)
fstpl -48(%edx)
fldl 120(%edx)
fldl -80(%ecx)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl -80(%ecx)
fxch %st(1)
fstpl 120(%edx)
fstpl -40(%edx)
fldl -128(%ecx)
fldl -72(%ecx)
fsubr %st(1),%st(0)
fmul %st(2),%st(0)
fsubr %st(0),%st(1)
faddl -72(%ecx)
fxch %st(1)
fstpl -128(%ecx)
fstpl -32(%edx)
fldl -120(%ecx)
fldl -64(%ecx)
fsubr %st(1),%st(0)
fmulp %st(0),%st(2)
fsub %st(1),%st(0)
fxch %st(1)
faddl -64(%ecx)
fxch %st(1)
fstpl -120(%ecx)
fstpl -24(%edx)
movl 180(%ecx),%esi
movl 184(%ecx),%ebp
sub  $1,%ebp
ja ._morebits
movl 188(%ecx),%edi
sub  $4,%edi
jb ._done
movl (%ebx,%edi),%esi
mov  $32,%ebp
jmp ._morebytes
._done:
movl 4(%esp,%eax),%eax
fldl 0(%esp)
fstpl 0(%eax)
fldl 8(%esp)
fstpl 8(%eax)
fldl 16(%esp)
fstpl 16(%eax)
fldl 24(%esp)
fstpl 24(%eax)
fldl 32(%esp)
fstpl 32(%eax)
fldl 40(%esp)
fstpl 40(%eax)
fldl 48(%esp)
fstpl 48(%eax)
fldl -120(%edx)
fstpl 56(%eax)
fldl -112(%edx)
fstpl 64(%eax)
fldl -104(%edx)
fstpl 72(%eax)
fldl -96(%edx)
fstpl 80(%eax)
fldl -88(%edx)
fstpl 88(%eax)
fldl -80(%edx)
fstpl 96(%eax)
fldl -72(%edx)
fstpl 104(%eax)
fldl -64(%edx)
fstpl 112(%eax)
fldl -56(%edx)
fstpl 120(%eax)
fldl -48(%edx)
fstpl 128(%eax)
fldl -40(%edx)
fstpl 136(%eax)
fldl -32(%edx)
fstpl 144(%eax)
fldl -24(%edx)
fstpl 152(%eax)
movl 160(%ecx),%eax
movl 164(%ecx),%ebx
movl 168(%ecx),%esi
movl 172(%ecx),%edi
movl 176(%ecx),%ebp
add %eax,%esp
ret
